<?php   
/**
 * Handle requrest of all process from
 * Advanced control panel
 * PHP version >= 5
 * @category ShirteeProducts
 * @package  ShirteeProducts
 * @author   Shirtee Team <mail@shirtee.com>
 * @license  GNU https://gnu.com
 * @link     https://www.shirtee.de
 */

/**
 * Handle all requests between Advanced control panel and
 * Woo store
 */
if (!class_exists('SHIRTEE_BRIDGE')) {
    
    class SHIRTEE_BRIDGE
    {
        /**
         * Holds a copy of itself, so it can be referenced by the class name.
         *
         * @since 3.10
         *
         * @var SHIRTEE_BRIDGE
         */
        public static $instance;

        /**
         * Holds a value of which member function needs to
         * request_method to invoke appropriate Shirtee API Request
         */
        protected $request_method = null;

        /**
         * Calls when object of class is created.
         *
         * @see SHIRTEE_BRIDGE::init()
         *
         * @since 3.10
         */
        public function __construct()
        {           
            if ($_SERVER['REMOTE_ADDR'] != '188.166.172.107') {                
                if( isset($_SERVER['HTTP_X_REAL_IP']) && $_SERVER['HTTP_X_REAL_IP'] != '188.166.172.107' ){
                    echo json_encode(array("status" => "error", "msg" => "You are not authorized to access this file..."));
                    exit;
                }
            }
            $this->init();
        }

        /**
         * Call when object of class created.
         *
         * @since  3.10
         * @return null
         */
        public function init()
        {

               
            $path      = getcwd();
            $root_path = explode("/wp-content", $path);
            include_once $root_path[0] . '/wp-load.php';
            include_once SHIRTEE_ROOT_DIR . '/includes/classes/class-shirtee-products-importer.php';
            $shirtee_importer_obj = new SHIRTEE_IMPORTER();
            if (!$shirtee_importer_obj->is_shirtee_plugin_activate() || !$shirtee_importer_obj->is_shirtee_required_plugin_activate()) {
                exit;
            }
            if (!function_exists('curl_init')) {
                $shirtee_importer_obj->send_emails("<p>We founds that curl is not enabled in your side. Please contact side administrator to enable the service of curl.</p>", "Fetch Products from Advanced control panel");
                return false;
            }

            /**
             * Exit if not defined access_data
             */

                    
            if (!isset($_POST['data']['access_data'])) {
               
                exit();
            }
            $this->request_method = $_POST['data']['access_data'];

            switch ($this->request_method) {
                case 'dropShipping_fetch_products':
                    return $this->dropShipping_fetch_products();
                    break;  
                case 'allImportProduct_fetch_products':
                    return $this->allImportProduct_fetch_products();
                    break;    
                case 'warehouse_fetch_products':
                    return $this->warehouseProduct_fetch_products();
                    break;    
                case 'sync_products':
                    return $this->syncProducts();
                    break;
                case 'update_shirtee_settings':
                    return $this->updateApiSettings();
                    break;
                case 'import_to_woocommerce':
                    return $this->importProductsToWoo();
                    break;
                case 'remove_products':
                    return $this->removeProducts();
                    break;
                case 'order_list':
                    return $this->wooOrderLists();
                    break;
                case 'resync_order':
                    return $this->reSyncOrder();
                    break;
                case 'product_list':
                    return $this->productListing();
                    break;
                case 'view_settings':
                    return $this->viewSettings();
                    break;
                case 'schedule_product':
                    return $this->scheduleProduct();
                    break;
                case 'cron_list':
                    return $this->cronListing();
                    break;
                case 'update_wallet':
                    return $this->updateWallet();
                    break;
                case 'migrate_data':
                    return $this->migrateData();
                    break;
                case 'warehouse_stock_update':
                    return $this->warehouseStockUpdate();
                    break; 
                case 'remove_woo_shirtee_id':
                    return $this->removewooshirteeID();
                    break;    
                case 'woo_shirtee_id_update':
                    return $this->wooshirteeIDUpdate();
                    break; 
                case 'woo_remove_api_token':
                    return $this->removeapitoken();
                    break;
                case 'shirtee_to_woo_sett':
                    return $this->updateshirteetowoosett();
                    break;  
                
            }
        }
        public function updateshirteetowoosett()
        {   
            $exclude_sett = $_POST['data']['designer_details'];

            $uptitle = $exclude_sett['product_title'];
            $updesc  = $exclude_sett['product_description'];
            $upprice = $exclude_sett['product_price'];
            $upimg   = $exclude_sett['product_image'];


            $shirtee_importer_obj = new SHIRTEE_IMPORTER();

            global $wpdb;
            $setting_table = "{$wpdb->prefix}shirtee_import_settings";
            $settings      = $shirtee_importer_obj->shirtee_settings();

            if (isset($uptitle)) 
            {
                $settings['product_title'] = isset($uptitle) && !empty($uptitle) ? $uptitle : '0';
            }

            if (isset($updesc)) 
            {
               $settings['product_description'] = isset($updesc) && !empty($updesc) ? $updesc : '0';
            }

            if (isset($upprice)) 
            {
                $settings['product_price'] = isset($upprice) && !empty($upprice) ? $upprice : '0';
            }

            if (isset($upimg)) 
            {
                $settings['product_image'] = isset($upimg) && !empty($upimg) ? $upimg : '0';
            }


            $settings = serialize($settings);
            if (!empty($settings)) {
                $wpdb->update(
                    $setting_table,
                    array(
                        "settings_value" => "{$settings}"
                    ),
                    array(
                        "settings_name"  => "import_settings"
                    )
                );
            } else {
                $wpdb->insert(
                    $setting_table,
                    array(
                        "settings_name"  => "import_settings",
                        "settings_value" => "{$settings}"
                    )
                );
            }

            return $content;
            //echo '<pre/>';print_r($content); exit;

        }
        public function removeapitoken(){
            global $wpdb;
            $import_settings_tbl = "{$wpdb->prefix}shirtee_import_settings";
            if (!isset($_POST['data']) && empty($_POST['data'])) {
                return false;
            }
            if (empty($settings_name = $_POST['data']['mage_products_ids']['settings_name'])) {
                return false;
            }
            $deleteRow = $wpdb->query("DELETE FROM {$import_settings_tbl} WHERE `settings_name` = '{$settings_name}'");
            
                if(!empty($deleteRow)){
                       $msg = 'Woo token row deleted sucessfully';
                }else{
                       $msg = 'some issue Woo token row not deleted';
                }
               echo json_encode($msg);
               exit;
        }
        public function removewooshirteeID(){
            global $wpdb;
            $order_list_tbl = "{$wpdb->prefix}shirtee_import_woo_orders";
            if (!isset($_POST['data']) && empty($_POST['data'])) {
                return false;
            }
            if (empty($woo_order_id = $_POST['data']['mage_products_ids']['woo_order_id'])) {
                return false;
            }
            $deleteRow = $wpdb->query("DELETE FROM {$order_list_tbl} WHERE `woo_order_ID` = '{$woo_order_id}'");
            
                if(!empty($deleteRow)){
                       $msg = 'Order Deleted Sucessfully';
                }else{
                       $msg = 'some issue order not deleted';
                }
               echo json_encode($msg);
               exit;
        }
        public function wooshirteeIDUpdate(){
            global $wpdb;
            $order_list_tbl = "{$wpdb->prefix}shirtee_import_woo_orders";
                      if (!isset($_POST['data']) && empty($_POST['data'])) {
                return false;
            }
           
            if (empty($woo_order_id = $_POST['data']['mage_products_ids']['woo_order_id'])) {
                return false;
            }
            if (empty($woo_shirtee_id = $_POST['data']['mage_products_ids']['woo_shirtee_id'])) {
                return false;
            }
             $updateOrder = $wpdb->update(
                     $order_list_tbl,
                    array(
                        "woo_shirtee_id"    => $woo_shirtee_id ,
                        "woo_shirtee_error" => '',
                        "status"            => 1,
                    ),
                    array(
                        "woo_order_ID"      => $woo_order_id
                    )
                );
               if(!empty($updateOrder)){
                $message ='Order Update Sucessfully';
                }else{
                 $message ='Some issue order not Updated';
                }
             echo json_encode($message);
            exit;
              
        }
        public function warehouseStockUpdate()
        {  
            if (!isset($_POST['data']) && empty($_POST['data'])) {
                return false;
            }
            
            /*if ( empty($_POST['data']['woo_key']) ) {
                return false;
            }*/
            
            //sku quantitity update
            $sku  = $_POST['data']['sku'];
            $available_stock = $_POST['data']['qty'];
            global $wpdb;          
            $tmp = 0;
            $variation  = $wpdb->get_results("SELECT * FROM {$wpdb->prefix}postmeta WHERE meta_value = '{$sku}'");
            foreach( $variation  as $single ){
                if( !empty($single) && isset($single->post_id) ) {
                    $new_stock = wc_update_product_stock($single->post_id, $available_stock, 'set', false); 
                    if( !empty($new_stock) ){
                       $tmp = 1;
                    } 
                }
                
            }
            if(  $tmp == 1 ){
                echo json_encode(array("status" => "success"));
                exit;
            } else {
                echo json_encode(array("status" => "fail"));
                exit;
            }
            //sku quantitity update end              
            
        }
        public function dropShipping_fetch_products()
        {             
            if (!isset($_POST['data']) && empty($_POST['data'])) {
                return false;
            }
            
            if ( empty($_POST['data']['woo_key']) || empty($_POST['data']['categoryID']) || empty($_POST['data']['designerID']) ) {
                return false;
            }
            
            $shirtee_importer_obj = new SHIRTEE_IMPORTER();
        
            global $wpdb;
            $setting_table = "{$wpdb->prefix}shirtee_import_settings";
            $settings      = $shirtee_importer_obj->shirtee_settings();
            $access_token       = $shirtee_importer_obj->shirtee_settings('access_token');
          
            $woo_key = $_POST['data']['woo_key'];            
            $categoryID = $_POST['data']['categoryID'];
            $designerID = $_POST['data']['designerID'];
            
            if( ($access_token == $woo_key) && ($settings['designer_id']==$designerID) &&  ($settings['catID']==$categoryID) ){
                    $res_data = $shirtee_importer_obj->execute_curl('', 'sync_data');
                    if ($res_data['status'] == "success") {
                        global $wpdb;
                        $tbl_product_list = "{$wpdb->prefix}shirtee_import_products";
                        $result   = $res_data['data'];
                        if (!empty($result)) {
                            foreach ($result as $r) {
                                $product_id = $r['product_id'];
                                $proInsed   = $wpdb->get_row("SELECT * FROM {$tbl_product_list} WHERE product_mage_id = {$product_id}");
                                if (!empty($proInsed)) {
                                    if (!in_array($proInsed->status, array(2, 3)) && ($proInsed->product_woo_id == '' || $proInsed->product_woo_id == 0)) {
                                       // $wpdb->query("UPDATE {$tbl_product_list} SET status = 0 WHERE product_mage_id = {$product_id}");
                                    }
                                } else {
                                    $wpdb->query("INSERT INTO {$tbl_product_list}( `product_mage_id`,`status` )VALUES('{$product_id}', 0)");
                                }
                            }                
                        } elseif (empty($result) && !isset($result['status'])) {
                            return wp_send_json(array("status" => "error", "msg" => __("<p>No Any Product Founds from the Shirtee Store...</p>", "shirtee-products-1")));
                        } 
                    } else {
                        return wp_send_json(array("status" => "error", "msg" => __($res_data['msg'], "shirtee-products-1")));
                    }
               
                    echo json_encode(array("status" => "success"));
                    exit; 
            } else {
                 echo json_encode(array("status" => "fail"));
                    exit;
            }
        }
        
        public function allImportProduct_fetch_products()
        {     
            if (!isset($_POST['data']) && empty($_POST['data'])) {
                return false;
            }
             
            if ( empty($_POST['data']['woo_key']) || empty($_POST['data']['categoryID']) || empty($_POST['data']['designerID']) ) {
              //  return false;
            }
            
            $shirtee_importer_obj = new SHIRTEE_IMPORTER();
        
            global $wpdb;
            $setting_table = "{$wpdb->prefix}shirtee_import_settings";
            $settings      = $shirtee_importer_obj->shirtee_settings();
            $access_token       = $shirtee_importer_obj->shirtee_settings('access_token');
          
            $woo_key = $_POST['data']['woo_key'];            
            $categoryID = $_POST['data']['categoryID'];
            $designerID = $_POST['data']['designerID'];
            $status = $_POST['data']['status'];
            $result = $_POST['data']['data'];
            //     echo "<pre>";
            //print_r($_POST); 
            //exit; 
            if( ($access_token == $woo_key) && ($settings['designer_id']==$designerID) &&  ($settings['catID']==$categoryID) ){
                    //$res_data = $shirtee_importer_obj->execute_curl('', 'sync_data');
                    if ( $status == "success") {
                        global $wpdb;
                        $tbl_product_list = "{$wpdb->prefix}shirtee_import_products";
                        //$result   = $res_data['data'];
                        if( !empty($result[0]['info']) && !empty($result[0]['options']) && !empty($result[0]['mediaList']) ) {
                            
                            foreach ($result as $data) { 
                                $product_id = $data['product_id'];
                                $sku = $data['info']['sku'];
                                $price = $data['info']['price'];
                                $info = $data['info'];
                                $product_title = $data['info']['variable_name'];
                                $product_type    = $data['info']['campaign_title'];
                                $options = $data['options'];
                                $optionsData = $options; 
                                $variation = count($optionsData[0]['additional_fields']);
                                $mediaList = $data['mediaList'];
                                
                                $proInsed   = $wpdb->get_row("SELECT * FROM {$tbl_product_list} WHERE product_mage_id = {$product_id}");
                                if (!empty($proInsed)) {
                                    if (!in_array($proInsed->status, array(2, 3)) && ($proInsed->product_woo_id == '' || $proInsed->product_woo_id == 0)) {
                                       // $wpdb->query("UPDATE {$tbl_product_list} SET status = 0 WHERE product_mage_id = {$product_id}");
                                    }
                                } else {                                  
                                    
                                    
                                     $result =  $wpdb->insert(
                                            $tbl_product_list,
                                            array(
                                            'product_mage_id'  => $product_id, 
                                            "product_title"      => esc_sql($product_title),
                                            "product_type"       => esc_sql($product_type),
                                            "product_sku"        => $sku,
                                            "product_price"      => $price,
                                            "product_data"       => json_encode($info),
                                            "product_attributes" => json_encode($options),
                                            "product_images"     => json_encode($mediaList),
                                            "product_variations" => $variation,
                                            "is_all_import"      => 1,
                                            "status"             => 1
                                            )
                                        );
                                    
                                        $import_cron = "{$wpdb->prefix}shirtee_import_product_insert_cron";
                                        $proInsed   = $wpdb->get_row("SELECT * FROM {$import_cron} WHERE mage_id = {$product_id}");
                                        if (!empty($proInsed)) {                                
                                            $wpdb->query("DELETE FROM {$import_cron} WHERE mage_id = {$product_id}");
                                        }
                                        $WpProductID=0;
                                        $prod_status="insert";
                                        $publish =1;
                                        $query = $wpdb->insert(
                                            $import_cron,
                                            array(
                                                "mage_id"        => $product_id,
                                                "woo_id"         => $WpProductID,
                                                "product_status" => $prod_status,
                                                "publish"        => $publish,
                                                "created_at"     =>  current_time('mysql'),
                                                "updated_at"     =>  current_time('mysql'),
                                                "status"         => 1,
                                            )
                                        );  
                                        $mage_products[0]['product_id']  = $product_id;
                                        $mage_products[0]['prod_status'] = "insert";
                                        $mage_products[0]['woo_id']      = 0;
                                        $mage_products[0]['url']         = '';
                                        $data = array(
                                            "mage_ids"  => $mage_products,
                                        );
                                        $response = $shirtee_importer_obj->execute_curl($data, "schedule_product");
                                  //  $wpdb->query("INSERT INTO {$tbl_product_list}( `product_mage_id`,`status` )VALUES('{$product_id}', 0)");
                                }
                            }                
                        } elseif (empty($result) && !isset($result['status'])) {
                            return wp_send_json(array("status" => "error", "msg" => __("<p>No Any Product Founds from the Shirtee Store...</p>", "shirtee-products-1")));
                        } 
                    } else {
                        return wp_send_json(array("status" => "error", "msg" => __($res_data['msg'], "shirtee-products-1")));
                    }
               
                    echo json_encode(array("status" => "success"));
                    exit; 
            } else {
                 echo json_encode(array("status" => "fail"));
                    exit;
            }
        }
        public function warehouseProduct_fetch_products()
        {     
            if (!isset($_POST['data']) && empty($_POST['data'])) {
                return false;
            }
             
            if ( empty($_POST['data']['woo_key']) || empty($_POST['data']['categoryID']) || empty($_POST['data']['designerID']) ) {
              //  return false;
            }
            
            $shirtee_importer_obj = new SHIRTEE_IMPORTER();
        
            global $wpdb;
            $setting_table = "{$wpdb->prefix}shirtee_import_settings";
            $settings      = $shirtee_importer_obj->shirtee_settings();
            $access_token       = $shirtee_importer_obj->shirtee_settings('access_token');
          
            $woo_key = $_POST['data']['woo_key'];            
            $categoryID = $_POST['data']['categoryID'];
            $designerID = $_POST['data']['designerID'];
            $status = $_POST['data']['status'];
            $result = array();
            $result = $_POST['data']['data'];                  
              
            
            if( ($access_token == $woo_key) && ($settings['designer_id']==$designerID) &&  ($settings['catID']==$categoryID) ){
                    //$res_data = $shirtee_importer_obj->execute_curl('', 'sync_data');
                    if ( $status == "success") {
                        global $wpdb;
                        $tbl_product_list = "{$wpdb->prefix}shirtee_import_products";
                        //$result   = $res_data['data'];
                        if( !empty($result[0]['info']) && !empty($result[0]['options']) ) {
                            
                            foreach ($result as $data) { 
                                $product_id = $data['product_id'];
                                $sku = $data['info']['sku'];
                                $ean_sku="";
                                if( isset($data['info']['ean_sku']) && !empty($data['info']['ean_sku']) ){
                                    $ean_sku = $data['info']['ean_sku'];
                                }
                                $price = $data['info']['price'];
                                $info = $data['info'];
                                $product_title = $data['info']['variable_name'];
                                $product_type    = $data['info']['campaign_title'];
                                $options = array();
                                $options = $data['options'];
                                $mediaList = $data['mediaList'];
                                
                                $varCount = "";                                
                                $varCount = count($options[2]['warehouse_variation']);
                                
                                
                                
                                
                                $proInsed   = $wpdb->get_row("SELECT * FROM {$tbl_product_list} WHERE product_mage_id = {$product_id}");
                                if (!empty($proInsed)) {
                                    
                                    $info['message']="Shipment approved";
                                    $wpdb->update(
                                        $tbl_product_list,
                                        array('product_data'=> json_encode($info),'product_attributes'=> json_encode($options)),
                                        array('ID' => $proInsed->ID)
                                    );
                                    
                                    $import_cron = "{$wpdb->prefix}shirtee_import_product_insert_cron";
                                    $proInsed   = $wpdb->get_row("SELECT * FROM {$import_cron} WHERE mage_id = {$product_id}");
                                    if (!empty($proInsed)) {                                
                                        $wpdb->query("DELETE FROM {$import_cron} WHERE mage_id = {$product_id}");
                                    }
                                    $WpProductID=0;
                                    $prod_status="insert";
                                    $publish =1;
                                    $query = $wpdb->insert(
                                        $import_cron,
                                        array(
                                        "mage_id"        => $product_id,
                                        "woo_id"         => $WpProductID,
                                        "product_status" => $prod_status,
                                        "publish"        => $publish,
                                        "created_at"     =>  current_time('mysql'),
                                        "updated_at"     =>  current_time('mysql'),
                                        "status"         => 1,
                                    )
                                    );  
                                    $mage_products[0]['product_id']  = $product_id;
                                    $mage_products[0]['prod_status'] = "insert";
                                    $mage_products[0]['woo_id']      = 0;
                                    $mage_products[0]['warehouse']    = 1;
                                    $mage_products[0]['url']         = '';
                                    $data = array(
                                        "mage_ids"  => $mage_products,
                                    );
                                    $response = $shirtee_importer_obj->execute_curl($data, "schedule_product");                                    
                                } else {                                  
                                    
                                    
                                     $result =  $wpdb->insert(
                                            $tbl_product_list,
                                            array(
                                            'product_mage_id'  => $product_id, 
                                            "product_title"      => esc_sql($product_title),
                                            "product_type"       => esc_sql($product_type),
                                            "product_sku"        => $sku,
                                            "ean_sku"            => $ean_sku,                                          
                                            "product_price"      => $price,
                                            "product_data"       => json_encode($info),
                                            "product_attributes" => json_encode($options),
                                            "product_images"     => json_encode($mediaList),
                                            "product_variations" => count($options[2]['warehouse_variation']),
                                            "is_warehouse"       => 1,
                                            "status"             => 1
                                            )
                                        );
                                }
                            }                
                        } elseif (empty($result) && !isset($result['status'])) {
                            return wp_send_json(array("status" => "error", "msg" => __("<p>No Any Product Founds from the Shirtee Store...</p>", "shirtee-products-1")));
                        } 
                    } else {
                        return wp_send_json(array("status" => "error", "msg" => __($res_data['msg'], "shirtee-products-1")));
                    }
               
                    echo json_encode(array("status" => "success"));
                    exit; 
            } else {
                 echo json_encode(array("status" => "fail"));
                    exit;
            }
        }
        public function syncProducts()
        {
            global $wpdb;
            $product_list = "{$wpdb->prefix}shirtee_import_products";

            if (!isset($_POST['data']) && empty($_POST['data'])) {
                return false;
            }

            $products = isset($_POST['data']['products']) && !empty($_POST['data']['products']) ? $_POST['data']['products'] : "";
            if (empty($products)) {
                return false;
            }
            $shirtee_importer_obj = new SHIRTEE_IMPORTER();
            $woo_token = $shirtee_importer_obj->shirtee_settings('woo_token');
            if( empty($woo_token) ){
                return false;
            }
            foreach ($products as $product) {
                $proInsed = $wpdb->get_row("SELECT `status`,`product_woo_id` FROM {$product_list} WHERE product_mage_id = {$product['product_id']}");
                if (!empty($proInsed)) {
                   // if (!in_array($proInsed->status, array(2, 3)) && ($proInsed->product_woo_id == '' || $proInsed->product_woo_id == 0)) {
                        $wpdb->update(
                            $product_list,
                            array(
                                "status"          => 0
                            ),
                            array(
                                "product_mage_id" => $product['product_id']
                            )
                        );
                   // }
                } else {
                    $wpdb->insert(
                        $product_list,
                        array(
                            "product_mage_id" => $product['product_id'],
                            "status"          => 0
                        )
                    );
                }
            }
            exit;
        }

        /**
         * Update Shirtee API settings
         *
         * @category ShirteeProducts
         * @package  ShirteeProducts
         * @author   Shirtee Team <mail@shirtee.com>
         * @license  GNU https://gnu.in
         * @link     https://www.shirtee.de
         * @return   null
         */
          public function updateApiSettings()
        {
            if (!isset($_POST['data']) && empty($_POST['data'])) {
                return false;
            }

            if (empty($new_settings = $_POST['data']['settings'])) {
                return false;
            }

            $shirtee_importer_obj = new SHIRTEE_IMPORTER();

            global $wpdb;
            $setting_table = "{$wpdb->prefix}shirtee_import_settings";
            $settings      = $shirtee_importer_obj->shirtee_settings();

            if (isset($new_settings['api_username']) && !empty($new_settings['api_username'])) {
                $settings['username'] = $new_settings['api_username'];
            }

            if (isset($new_settings['api_password']) && !empty($new_settings['api_password'])) {
                $settings['password'] = $new_settings['api_password'];
            }
            if (isset($new_settings['woocommerce_category_id']) && !empty($new_settings['woocommerce_category_id'])) {
                $settings['catID'] = $new_settings['woocommerce_category_id'];
            }
            if (isset($new_settings['woocommerce_designer_id']) && !empty($new_settings['woocommerce_designer_id'])) {
                $settings['designer_id'] = $new_settings['woocommerce_designer_id'];
            }
            if (isset($new_settings['email_id']) && !empty($new_settings['email_id'])) {
                $settings['email'] = $new_settings['email_id'];
            }
            if (isset($new_settings['api_dropshipping']) && !empty($new_settings['api_dropshipping'])) {
                $settings['dropshipping'] = $new_settings['api_dropshipping'];
            }
            if (isset($new_settings['product_status'])) {
                $settings['product_status'] = isset($new_settings['product_status']) && !empty($new_settings['product_status']) ? $new_settings['product_status'] : '0';
            }
            if (isset($new_settings['product_swatches'])) {
               $settings['product_swatches'] = isset($new_settings['product_swatches']) && !empty($new_settings['product_swatches']) ? $new_settings['product_swatches'] : '0';
            }
            if (isset($new_settings['product_title'])) {
                $settings['product_title'] = isset($new_settings['product_title']) && !empty($new_settings['product_title']) ? $new_settings['product_title'] : '0';
            }
            if (isset($new_settings['product_description'])) {
               $settings['product_description'] = isset($new_settings['product_description']) && !empty($new_settings['product_description']) ? $new_settings['product_description'] : '0';
            }
            if (isset($new_settings['product_price'])) {
                $settings['product_price'] = isset($new_settings['product_price']) && !empty($new_settings['product_price']) ? $new_settings['product_price'] : '0';
            }
            $settings = serialize($settings);
            if (!empty($settings)) {
                $wpdb->update(
                    $setting_table,
                    array(
                        "settings_value" => "{$settings}"
                    ),
                    array(
                        "settings_name"  => "import_settings"
                    )
                );
            } else {
                $wpdb->insert(
                    $setting_table,
                    array(
                        "settings_name"  => "import_settings",
                        "settings_value" => "{$settings}"
                    )
                );
            }
            exit;
        }

        /**
         * Schedule product to import/update into store from Advanced panel
         *
         * @category ShirteeProducts
         * @package  ShirteeProducts
         * @author   Shirtee Team <mail@shirtee.com>
         * @license  GNU https://gnu.in
         * @link     https://www.shirtee.de
         * @return   null
         */
        public function importProductsToWoo()
        {
            if (!isset($_POST['data']) && empty($_POST['data'])) {
                return false;
            }
            if (empty($products_ids = $_POST['data']['mage_products_ids'])) {
                return false;
            }
            global $wpdb;
            $product_list = "{$wpdb->prefix}shirtee_import_products";
            $import_list  = "{$wpdb->prefix}shirtee_import_product_insert_cron";

            foreach ($products_ids as $products) {
                $check_product = $wpdb->get_row("SELECT `product_woo_id`,`status` FROM {$product_list} WHERE `product_mage_id` = {$products} AND `status` = 1");
                if (empty($check_product)) {
                    continue;
                }

                $woo_id = 0;
                $status = 'insert';
                $uid    = 1;
                // Update Queue
                if ($check_product->product_woo_id != 0 || !empty($check_product->product_woo_id)) {
                    $woo_id = $check_product->product_woo_id;
                    $status = 'update';
                }
                $check_product_in_schedule = $wpdb->get_row("SELECT `woo_id`,`status` FROM {$import_list} WHERE `mage_id` = {$products}");
                if (empty($check_product_in_schedule)) {
                    $wpdb->insert(
                        $import_list,
                        array(
                            'uid'            => $uid,
                            'mage_id'        => $products,
                            'woo_id'         => $woo_id,
                            'product_status' => $status,
                            'created_at'     => current_time('mysql'),
                            'updated_at'     => current_time('mysql'),
                            'status'         => 1
                        )
                    );
                } else {
                    $wpdb->update(
                        $import_list,
                        array(
                            'woo_id'         => $woo_id,
                            'product_status' => $status,
                            'updated_at'     => current_time('mysql'),
                            'status'         => 1
                        ),
                        array(
                            'mage_id'        => $products,
                        )
                    );
                }
            }
            exit;
        }

        /**
         * Schedule product to import/update into store from Advanced panel
         *
         * @category ShirteeProducts
         * @package  ShirteeProducts
         * @author   Shirtee Team <mail@shirtee.com>
         * @license  GNU https://gnu.in
         * @link     https://www.shirtee.de
         * @return   null
         */
        public function removeProducts()
        {
            if (!isset($_POST['data']) && empty($_POST['data'])) {
                return false;
            }
            if (empty($products_ids = $_POST['data']['mage_products_ids'])) {
                return false;
            }

            global $wpdb;
            $product_list = "{$wpdb->prefix}shirtee_import_products";

            foreach ($products_ids as $product) {
                $get_woo  = $wpdb->get_row("SELECT `product_woo_id` FROM {$product_list} WHERE `product_mage_id` = '{$product}'");
                $products = $wpdb->get_row("DELETE FROM {$product_list} WHERE `product_mage_id` = '{$product}'");
                if (!is_wp_error($products)) {
                    if (!empty($get_woo) && ($get_woo->product_woo_id != '' || $get_woo->product_woo_id != 0)) {
                        //wp_delete_post($get_woo->product_woo_id);
                        remove_product_info($product, $get_woo->product_woo_id);
                    }
                    $message['mageIds']['success'][] = $product;
                } else {
                    $message['mageIds']['error'][]   = $product;
                }
            }
            echo json_encode($message);
            exit;
        }

        /**
         * Order list
         *
         * @category ShirteeProducts
         * @package  ShirteeProducts
         * @author   Shirtee Team <mail@shirtee.com>
         * @license  GNU https://gnu.in
         * @link     https://www.shirtee.de
         * @return   null
         */
        public function wooOrderLists()
        {
            global $wpdb;
            $order_tbl = "{$wpdb->prefix}shirtee_import_woo_orders";
            $orders = $wpdb->get_results("SELECT * FROM {$order_tbl}");
            if (empty($orders)) {
                echo json_encode(array("status" => "error", "msg" => "No Orders founds..."));
                exit;
            }
            echo json_encode(array("status" => "success", "count" => count($orders), "msg" => $orders));
            exit;
        }

        /**
         * Re-schedule Order if there are any errors
         *
         * @category ShirteeProducts
         * @package  ShirteeProducts
         * @author   Shirtee Team <mail@shirtee.com>
         * @license  GNU https://gnu.in
         * @link     https://www.shirtee.de
         * @return   null
         */
        public function reSyncOrder()
        {
            if (!isset($_POST['data']) && empty($_POST['data'])) {
                echo json_encode(array("status" => "error", "msg" => "Oops! Missing Required fields"));
                exit;
            }
            if (empty($order_ids = $_POST['data']['woo_order_id'])) {
                echo json_encode(array("status" => "error", "msg" => "Oops! Missing Required fields"));
                exit;
            }

            $order_ids = explode(",", $order_ids);

            global $wpdb, $woocommerce;
            $order_tbl = "{$wpdb->prefix}shirtee_import_woo_orders";

            foreach ($order_ids as $order) {
                if (is_null(get_post($order))) {
                    $message[] = array(
                        "status" => "error",
                        "id"     => $order,
                        "msg"    => "Order ID not exists in Woocommerce"
                    );
                    continue;
                }
                $updateOrder = $wpdb->update(
                    $order_tbl,
                    array(
                        "status"            => 0,
                        "woo_shirtee_id"    => null,
                        "woo_shirtee_error" => null,
                    ),
                    array(
                        "woo_order_ID"      => $order
                    )
                );
                if ($updateOrder === false) {
                    $message[] = array(
                        "status" => "error",
                        "id"     => $order,
                        "msg"    => $wpdb->last_query
                    );
                } else {
                    $message[] = array(
                        "status" => "success",
                        "id"     => $order,
                        "msg"    => "Order updated successfully"
                    );
                }
            }
            echo json_encode($message);
            exit;
        }

        /**
         * Re-schedule Order if there are any errors
         *
         * @category ShirteeProducts
         * @package  ShirteeProducts
         * @author   Shirtee Team <mail@shirtee.com>
         * @license  GNU https://gnu.in
         * @link     https://www.shirtee.de
         * @return   null
         */
        public function productListing()
        {
            global $wpdb, $woocommerce;
            $product_tbl = "{$wpdb->prefix}shirtee_import_products";

            $products = $wpdb->get_results("SELECT ID,product_mage_id,product_woo_id,product_type,product_sku,product_variations,status FROM {$product_tbl}");
            if (empty($products)) {
                echo json_encode(array("status" => "error", "msg" => "No Products Founds..."));
                exit;
            }
            echo json_encode(array("status" => "success", "count" => count($products), "msg" => $products));
            exit;
        }
        
        public function cronListing()
        {
            global $wpdb, $woocommerce;
            $product_tbl = "{$wpdb->prefix}shirtee_import_product_insert_cron";

            $products = $wpdb->get_results("SELECT * FROM {$product_tbl}");
            if (empty($products)) {
                echo json_encode(array("status" => "error", "msg" => "No Products Founds..."));
                exit;
            }
            echo json_encode(array("status" => "success", "count" => count($products), "msg" => $products));
            exit;
        }
        /**
         * Re-schedule Order if there are any errors
         *
         * @category ShirteeProducts
         * @package  ShirteeProducts
         * @author   Shirtee Team <mail@shirtee.com>
         * @license  GNU https://gnu.in
         * @link     https://www.shirtee.de
         * @return   null
         */
        public function viewSettings()
        {
            $shirtee_importer_obj = new SHIRTEE_IMPORTER();
            $settings = $shirtee_importer_obj->shirtee_settings();
            if (empty($settings)) {
                echo json_encode(array("status" => "error", "msg" => "Settings not founds..."));
                exit;
            }
            $system_status = $shirtee_importer_obj->get_environment_info();
            $system = array();
            $system['memory_limit'] = size_format($system_status['wp_memory_limit']);
            $system['php_max_execution_time'] = $system_status['php_max_execution_time'];
            $system['php_input_time'] = $system_status['php_max_input_time'];
            $system['max_upload_size'] = size_format($system_status['max_upload_size']);
            $system['php_post_max_size'] = size_format($system_status['php_post_max_size']);
            $system['plugin_version'] = PLUGIN_VERSION;
           
            echo json_encode(array("status" => "success", "msg" => $settings, "system" => $system));
            exit;
        }

        /**
         * Re-schedule Order if there are any errors
         *
         * @category ShirteeProducts
         * @package  ShirteeProducts
         * @author   Shirtee Team <mail@shirtee.com>
         * @license  GNU https://gnu.in
         * @link     https://www.shirtee.de
         * @return   null
         */
        public function scheduleProduct()
        {
            if (!isset($_POST['data']) && empty($_POST['data'])) {
                echo json_encode(array("status" => "error", "msg" => "Oops! Missing Required fields"));
                exit;
            }
            if (empty($products = $_POST['data']['products'])) {
                echo json_encode(array("status" => "error", "msg" => "Oops! Missing Required fields"));
                exit;
            }
            $shirtee_importer_obj = new SHIRTEE_IMPORTER();
            $message = $shirtee_importer_obj->woo_product_schedule_process($products);
            echo $message;
            exit;
        }

        /**
         * Migrate data from WOO to SHIRTEE advanced control panel
         *
         * @category ShirteeProducts
         * @package  ShirteeProducts
         * @author   Shirtee Team <mail@shirtee.com>
         * @license  GNU https://gnu.in
         * @link     https://www.shirtee.de
         * @return   null
         */
        public function migrateData()
        {
            $shirtee_importer_obj = new SHIRTEE_IMPORTER();
            $chk_migrate = $shirtee_importer_obj->shirtee_settings('is_migrated');
            if ($chk_migrate == "yes") {
                return false;
            }
            global $wpdb;
            $tbl_products = "{$wpdb->prefix}shirtee_import_products";
            $tbl_schedule = "{$wpdb->prefix}shirtee_import_product_insert_cron";
            $tbl_orders   = "{$wpdb->prefix}shirtee_import_woo_orders";
            $tbl_settings = "{$wpdb->prefix}shirtee_import_settings";

            $products     = $wpdb->get_results("SELECT * FROM {$tbl_products}", ARRAY_A);
            $schedule     = $wpdb->get_results("SELECT * FROM {$tbl_schedule}", ARRAY_A);
            $orders       = $wpdb->get_results("SELECT * FROM {$tbl_orders}", ARRAY_A);

            if (!empty($products)) {
                for ($p = 0; $p < count($products); $p++) {
                    if ($products[$p]['product_woo_id'] != 0 || !empty($products[$p]['product_woo_id'])) {
                        $products[$p]['url'] = get_the_permalink($products[$p]['product_woo_id']);
                        $products[$p]['shirtee_woo_status'] = 2;
                    }
                }
            }

            if (!empty($orders)) {
                $order_wp_data = array();
                for ($o = 0; $o < count($orders); $o++) {
                    if (is_null(get_post($orders[$o]['woo_order_ID']))) {
                        continue;
                    }

                    $order      = wc_get_order($orders[$o]['woo_order_ID']);
                    $order_data = $order->get_data();

                    $order_wp_data[$o]['info']['site_url']       = rtrim(site_url(), "/");
                    $order_wp_data[$o]['info']['type']           = SHIRTEE_APP;

                    $order_wp_data[$o]['info']['order_woo_id']   = $order_data['id'];
                    $order_wp_data[$o]['info']['order_email']    = $order_data['billing']['email'];
                    $order_wp_data[$o]['info']['order_date']     = $order_data['date_created']->date('Y-m-d H:i:s');
                    $order_wp_data[$o]['info']['order_price']    = $order_data['total'];
                    $order_wp_data[$o]['info']['currency']       = $order_data['currency'];
                    $order_wp_data[$o]['info']['status']         = $order_data['status'];
                    $order_wp_data[$o]['info']['discount']       = $order_data['discount_total'];
                    $order_wp_data[$o]['info']['discount_tax']   = $order_data['discount_tax'];
                    $order_wp_data[$o]['info']['total_tax']      = $order_data['total_tax'];
                    $order_wp_data[$o]['info']['billing']        = $order_data['billing'];
                    $order_wp_data[$o]['info']['shipping']       = $order_data['shipping'];
                    $order_wp_data[$o]['info']['shirtee_id']     = $orders[$o]['woo_shirtee_id'];
                    $order_wp_data[$o]['info']['process_status'] = $orders[$o]['status'];

                    $items = $order->get_items();
                    $p = 0;
                    foreach ($items as $item) :
                        $variation_id = 0;
                        $product_id = $item['product_id'];
                        if(!empty($product_id)){
                            $price = get_post_meta($product_id, '_regular_price', true);
                            $product_sku = get_post_meta($product_id, '_sku', true);
                            $order_wp_data[$o]['info']['items'][$p]['sku'] = $product_sku;
                            if (function_exists('wc_get_product')) :
                                if (wc_get_product($product_id)->is_type('variable')) :
                                    $variation_id  = $item['variation_id'];
                                    $price         = get_post_meta($variation_id, '_regular_price', true);
                                    $variation_sku = get_post_meta($variation_id, '_sku', true);
                                    $variation_sku = str_replace("--", "__", $variation_sku);
                                    $order_wp_data[$o]['info']['items'][$p]['sku'] = $variation_sku;
                                endif;
                            endif;
                            $qty = $item['quantity'];
                            $order_wp_data[$o]['info']['items'][$p]['product_id']   = $product_id;
                            $order_wp_data[$o]['info']['items'][$p]['product_name'] = $item['name'];
                            $order_wp_data[$o]['info']['items'][$p]['qty']          = $qty;
                            $order_wp_data[$o]['info']['items'][$p]['item_price']   = !empty($price) ? $price : $item['total'] / $qty;
                            $order_wp_data[$o]['info']['items'][$p]['item_tax']     = $item['total_tax'] != '' ? $item['total_tax'] : '0.00';
                            $order_wp_data[$o]['info']['items'][$p]['shipping_tax'] = $order_data['shipping_tax'] != '' ? $order_data['shipping_tax'] : '0.00';
                            $order_wp_data[$o]['info']['items'][$p]['shipping_amt'] = $order_data['shipping_total'] != '' ? $order_data['shipping_total'] : '0.00';
                            $p++;
                        }    
                    endforeach;
                }
            }

            $data = array(
                'products'  => $products,
                'schedule'  => $schedule,
                'orders'    => $order_wp_data,
            );
            $res_data = $shirtee_importer_obj->execute_curl($data, 'migrate_data');
            if ($res_data['status'] == 'success') {
                if ($chk_migrate == 0) {
                    $wpdb->update(
                        $tbl_settings,
                        array(
                            "settings_value" => "yes"
                        ),
                        array(
                            "settings_name"  => "is_migrated"
                        )
                    );
                } else {
                    $wpdb->insert(
                        $tbl_settings,
                        array(
                            "settings_name"  => "is_migrated",
                            "settings_value" => "yes"
                        )
                    );
                }
            }
        }

        /**
         * Put orders in schedule to sync with Shirtee after wallet udpate
         *
         * @category ShirteeProducts
         * @package  ShirteeProducts
         * @author   Shirtee Team <mail@shirtee.com>
         * @license  GNU https://gnu.in
         * @link     https://www.shirtee.de
         * @return   null
         */

        public function updateWallet()
        {
            global $wpdb;
            $tbl_order = "{$wpdb->prefix}shirtee_import_woo_orders";
            $orders    = $wpdb->get_results("SELECT ID from {$tbl_order} WHERE status = 5");
            if (empty($orders)) {
                die();
            }
            foreach ($orders as $order) {
                $wpdb->update(
                    $tbl_order,
                    array(
                        "status"            => 0,
                        "woo_shirtee_error" => NULL
                    ),
                    array(
                        "status"  => 5
                    )
                );
            }
        }
    }
    new SHIRTEE_BRIDGE;
}