<?php
/**
 * Process woo orders to shirtee store.
 *
 * PHP version >= 5
 *
 * @category  ShirteeProducts
 * @package   ShirteeProductsImporter
 * @author    Shirtee Team <mail@shirtee.com>
 * @copyright 2019 Shirtee
 * @license   GTU www.gtu.in
 * @link      www.shirtee.com
 * @since     1.5
 */
set_time_limit(0);
$path      = getcwd();
$root_path = explode("/wp-content", $path);
require $root_path[0].'/wp-load.php';
require SHIRTEE_ROOT_DIR.'/includes/classes/class-shirtee-products-importer.php';
$shirtee_importer_obj = new SHIRTEE_IMPORTER();
if (!$shirtee_importer_obj->is_shirtee_plugin_activate() ||!$shirtee_importer_obj->is_shirtee_required_plugin_activate()) {
    exit;
}
$import_settings          = $shirtee_importer_obj->shirtee_settings('import_settings'); //get woo token
if ($shirtee_importer_obj->is_migrated() == 'no') {
    return false;
}

global $wpdb;
$order_cron = "{$wpdb->prefix}shirtee_import_woo_orders";
$shirtee_import_products = $wpdb->prefix."shirtee_import_products"; //shirtee product table
$limit      = isset($_GET['limit']) ? $_GET['limit'] : 1;
$orders     = $wpdb->get_results("SELECT ID,woo_order_ID FROM {$order_cron} WHERE status = 0 LIMIT {$limit}");
if (!empty($orders)) {
    foreach ($orders as $key => $order) {
        $wpdb->update(
            $order_cron,
            array(
                'status' => 4,
            ),
            array(
                'ID'     => $order->ID
            )
        );
        if (is_null(get_post($order->woo_order_ID))) {
            $orders = array_diff(array($orders), array($order));
            $wpdb->update(
                $order_cron,
                array(
                    'status'            => 2,
                    'woo_shirtee_error' => "Order {$order->woo_order_ID} not exists in woocommerce.So, order was not processed to Shirtee store.",
                ),
                array(
                    'ID' => $order->ID
                )
            );
            $shirtee_importer_obj->send_emails("<p>Order {$order->woo_order_ID} not exists in woocommerce so order was not processed to Shirtee store.</p>", "Sync order to shirtee");
            continue;
        }
    }
}

/**
 * Check again for not empty $orders array
 * due to we skip orders which are removed from woocommerce
 */
if (!empty($orders)) {
    try {
        foreach ($orders as $order) {
            $order_id = $order->woo_order_ID;
            // Check if order was already processed to Shirtee
            if (get_post_meta($order_id, 'export_success', true) == 1) {
                $wpdb->update(
                    $order_cron,
                    array(
                        'status' => 1,
                    ),
                    array(
                        'ID'     => $order->ID
                    )
                );
                continue;
            }
            $order_info = wc_get_order($order_id);
            $order_data = $order_info->get_data();

            // Process order to shirtee if order status is Processing or completed
            if (!in_array($order_data['status'], array('processing', 'completed'))) {
                $wpdb->update(
                    $order_cron,
                    array(
                        'status'            => 1,
                        'woo_shirtee_error' => "Order not processed to Shirtee due to order status is {$order_data['status']}",
                    ),
                    array(
                        'ID'                => $order->ID
                    )
                );
                continue;
            }

            $items = $order_info->get_items();
            $data = array();
            $p = 0;
            $totalPrice = 0;
            if (!empty($items)) {
                foreach ($items as $item_id => $item) {
                   
                    $options      = array();
                    $sizeAttrID   = $attrSizeID = $colorAttrID = $attrColorID = $size = $color = $variation_sku = '';
                    $variation_id = 0;
                    $product_id   = $item['product_id'];
                    $price = get_post_meta($product_id, '_regular_price', true);
                    if (!empty($item['variation_id'])) {
                        $variation_id = $item['variation_id'];
                        $price = get_post_meta($variation_id, '_regular_price', true);
                        $variation_sku = get_post_meta($variation_id, '_sku', true);
                    } else {
                        $variation_sku = get_post_meta($product_id, '_sku', true); // for simple product 
                    }
                    $qty         = $item['quantity'];
                    $product_sku = get_post_meta($product_id, '_sku', true);
                    
                    $variableProduct = 0;    
                    if(!empty($product_sku)){ //check sku not empty   
                        if (function_exists('wc_get_product')) {
                            if (wc_get_product($product_id)->is_type('variable')) {
                                $variation_sku = str_replace("--", "__", get_post_meta($variation_id, '_sku', true));
                                $attributes    = explode("__", $variation_sku);
                                $product_sku = $attributes[0];
                                $size          = isset($attributes[1]) ? $attributes[1] : '';
                                $color         = isset($attributes[2]) ? $attributes[2] : '';
                                $variableProduct = 1;
                            }
                        }                            
                        $res_data = array();                       
                       
                        $product_attributes = $wpdb->get_results( "SELECT product_attributes,product_attributes_new,is_all_import,is_warehouse,ean_sku FROM $shirtee_import_products WHERE product_sku = '{$product_sku}' or (product_attributes LIKE '%{$variation_sku}%' and product_attributes not LIKE '%{$variation_sku}-%')    LIMIT 1" );
                      
                        $warehouseOrder = 0;
                        $firstword = explode("_",$variation_sku);
                        if( !empty($product_attributes) ){
                            $res_data['status']="success";
                            $res_data['msg']="attributes founds...";
                            if($product_attributes[0]->is_all_import == 1)
                            {
                               $res_data['data']['attributes'] = json_decode($product_attributes[0]->product_attributes,true);
                                $sku = $product_sku;
                            } else {
                                if( !empty($product_attributes[0]->product_attributes_new) ){
                                    $res_data['data']['attributes'] = json_decode($product_attributes[0]->product_attributes_new,true);
                                } else {
                                    if($product_attributes[0]->is_warehouse == 1){
                                        $res_data['data']['attributes'] = json_decode($product_attributes[0]->product_attributes,true);
                                    } else {
                                        $res_data['data']['attributes'] = unserialize($product_attributes[0]->product_attributes);
                                    }
                                }
                            }
                        } if( $firstword[0] == "SWP" ){
                            $warehouseOrder = 1;
                        } else {
                            $data['products'] = $sku = $product_sku;
                            $res_data = $shirtee_importer_obj->execute_curl($data, 'product_options');  
                                                
                            if( $res_data['status'] == "error" ){
                                continue;
                            }
                        }
                        
                        
                        
                        
                        if( $warehouseOrder == 1 ){  
                             $variation_sku = $variation_sku;
                           /* $tempsku = "";
                            foreach ($res_data['data']['attributes'][2]['warehouse_variation']  as $optionsList ) {                                
                                if( isset($optionsList['ean_sku']) && $optionsList['ean_sku'] == $variation_sku ){
                                    $variation_sku = $optionsList['sku'];
                                    $tempsku =  $optionsList['sku'];
                                } 
                            }
                            if(empty($tempsku) ){
                                continue;
                            }*/
                        }
                         
                        
                       // echo "<pre>";print_r($product_attributes);exit;
                        if ( $warehouseOrder == 0  ) {
                            foreach ($res_data['data']['attributes'] as $attrkey => $optionsList) {
                                $sku = "";
                                if (count($optionsList['additional_fields']) == 1) {
                                    $sku .= $product_sku;
                                    if ($optionsList['title'] == 'size') {
                                        $sizeAttrID = $optionsList['additional_fields'][0]['value_id'];
                                        $attrSizeID = $attrkey;
                                        if (wc_get_product($product_id)->is_type('simple')) {
                                            $sku .= "__".$optionsList['additional_fields'][0]['sku'];
                                        }
                                    } elseif ($optionsList['title'] == 'color') {
                                        $colorAttrID = $optionsList['additional_fields'][0]['value_id'];
                                        $attrColorID = $attrkey;
                                        if (wc_get_product($product_id)->is_type('simple')) {
                                            $sku .= "__".$optionsList['additional_fields'][0]['value_id'];
                                        }
                                    }
                                } else {
                                    foreach ($optionsList['additional_fields'] as $additional_fields) {
                                        if ($optionsList['title'] == 'size') {
                                            if ($additional_fields['sku'] == $size) {
                                                $sizeAttrID = $additional_fields['value_id'];
                                                $attrSizeID = $attrkey;
                                            }
                                        } elseif ($optionsList['title'] == 'color') {
                                            if ($additional_fields['sku'] == $color) {
                                                $colorAttrID = $additional_fields['value_id'];
                                                $attrColorID = $attrkey;
                                            }
                                        }
                                    }
                                }
                            }
                            if (!empty($attrSizeID) && !empty($sizeAttrID) && !empty($attrColorID) && !empty($colorAttrID)) {
                                $options[$attrSizeID]  = $sizeAttrID;
                                $options[$attrColorID] = $colorAttrID;
                            }
                             
                        }
                        
                        $item_info[$p] = array(
                            "product_id"   => $product_id,
                            "product_name" => str_replace("'", "-", $item['name'] ), //updated 11-03-22
                            "qty"          => $qty,
                            "item_price"   => !empty($price) ? $price : $item['total'] / $qty,
                            "item_tax"     => $item['total_tax'] != '' ? $item['total_tax'] : '0.00',
                            "shipping_tax" => $order_data['shipping_tax'],
                            "shipping_amt" => $order_data['shipping_total'],
                            "sku"          => !empty($variation_sku) ? $variation_sku : $sku,
                        );
                        if ( get_option('woocommerce_prices_include_tax') == 'yes'){
                            $item_info[$p]['item_price'] =  $price;                                
                            $totalPrice += $price;
                        }  else {
                            $item_info[$p]['item_price'] = $price + $item['total_tax'];
                            $totalPrice += $price + $item['total_tax'];
                        }
                            
                        $custom_text = wc_get_order_item_meta($item_id, 'Custom Field', true);
                       
                     
                        if( $warehouseOrder == 1) {
                                $str = $variation_sku;                   
                                
                                $variation_sku = str_replace("--", "__", $str);
                                $attributes    = explode("__", $variation_sku);
                                $size          = isset($attributes[1]) ? $attributes[1] : '';
                                $color         = isset($attributes[2]) ? $attributes[2] : '';
                                $main_sku      = $attributes[0];
                                $attributes    = explode("_", $attributes[0]);
                            
                                
                                $firstskuChar = $attributes[0];
                                $secondskuChar = $attributes[1];
                                $colorcode = $color;
                                $sizecode = $size;
                            
                                //warehouse data code
                                $url = "https://dashboard.shirtee.cloud/APIgetTitleForWarehousePorduct";
                                //$params = array('sku' => "SWP_87UBS542", 'color' => "86913", 'size' => "41572");
                                $params = array('sku' => $main_sku , 'color' => $color, 'size' => $size);
                          
                                
                                $ch = curl_init();
                                curl_setopt($ch, CURLOPT_URL, $url);
                                curl_setopt($ch, CURLOPT_POST, 1);
                                curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
                                curl_setopt($ch, CURLOPT_POSTFIELDS, http_build_query($params));
                                curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
                                $response = curl_exec($ch);
                                $data = json_decode($response, true);
                                
                                $msg = "";
                                if( isset($data['msg']) && isset($data['status']) && ($data['status']=="success") ) {
                                    $msg = $data['msg'];
                                }
                                //$msg = 'SWP_EJX79T80__64134__41572 ## Woo Warehouse Test 18092020 || L || Black'; 
                                //warehouse data code
                               // if( $variableProduct == 0 ){
                                    $msgdata = explode("||", $msg);
                                    $msg  = $msgdata[0];
                                //}
                               
                                $products[] =[
                                    'qty' => $qty,
                                    'sku' => "OJOKZQ59_SLVLBL",
                                    'options' => [
                                        '1027034916' => "6928",
                                        '9027034916' => "6921"
                                    ],
                                    'custom_price' => $price,
                                    'custom_name' => $msg,
                                    'custom_designer_id' =>  $import_settings['designer_id']
                                ];

                                if( isset($import_settings['dropshipping']) && ( $import_settings['dropshipping'] == 'yes' ) ){
                                    $products[$p]['sku'] = "DRDVO8GMA7_WRHSNG"; 
                                    $products[$p]['options'] = array("1000011179" => "6868", "9000011179" => "6869");
                                } else {
                                    $products[$p]['sku'] = "BCS0ZR86_WRHSNG"; 
                                    $products[$p]['options'] = array("1027034916" => "6928", "9027034916" => "6921");
                                }

                                 
                        } else {   
                            if (!empty(trim($custom_text))) {
                                $products[] = [
                                    'qty'         => $qty,
                                    'sku'         => $product_sku,
                                    'options'     => $options,
                                    'custom_text' => $custom_text
                                ];
                            } else {
                                $products[] = [
                                    'qty'     => $qty,
                                    'sku'     => $product_sku,
                                    'options' => $options
                                ];
                            }
                            if( $import_settings['designer_id'] == 81248 ){
                                  $products[$p]['custom_price'] = "0.01";
                            }
                         }
                        $p++;                        
                    }
                    
                }       
                $first_name = str_replace("'", "-", $order_data['billing']['first_name']);     
                $last_name = str_replace("'", "-", $order_data['billing']['last_name']);     
                $order_wp_data = array(
                    "info"                  => array(
                        "site_url"          => rtrim(site_url(), "/"),
                        "type"              => defined('SHIRTEE_APP') ? SHIRTEE_APP : 1,
                    ),
                    "order_info"            => array(
                        "woo_order_id"      => $order_id,
                        "woo_order_email"   => $order_data['billing']['email'],
                        "woo_order_date"    => $order_data['date_created']->date('Y-m-d H:i:s'),
                        "woo_order_price"   => $totalPrice,
                        "status"            => $order_data['status'],
                        "woo_order_data"    => array(
                            "discount"      => $order_data['discount_total'],
                            "currency"      => $order_data['currency'],
                            "discount_tax"  => $order_data['discount_tax'],
                            "total_tax"     => $order_data['total_tax'],
                            "items"         => $item_info,
                        ),
                        "billing"           => str_replace("'", "-", $order_data['billing'] ),
                        "shipping"          => str_replace("'", "-", $order_data['shipping'] ),
                        "woo_customer_name" => $first_name." ".$last_name
                    )
                );
    
                $site_url = preg_replace('#^https?://#', '', site_url());
                $comment  = "From: WooCommerce; Store: {$site_url}; Remote order ID:{$order_id};";
    
                $data = array(
                    "plateform"  => "WP",
                    "products"   => $products,
                    "order_data" => $order_wp_data,
                    "comment"    => $comment
                );                
                $res_data = $shirtee_importer_obj->execute_curl($data, 'create_order');


                $d = date("j-M-Y H:i:s e").' == create_order ==';
                $str = json_encode($res_data);
                error_log("[$d] [$str]", 3, $_SERVER['DOCUMENT_ROOT'] ."/woowarehouse/wordpress.log");

                if ($res_data['status'] == 'success') {
                    update_post_meta($order_id, 'shirtee_ID', $res_data['data']);
                    update_post_meta($order_id, 'export_success', '1');
                    $wpdb->update(
                        $order_cron,
                        array(
                            'status' => 1,
                            'woo_shirtee_id' => $res_data['data'],
                        ),
                        array(
                            'ID' => $order->ID
                        )
                    );
                } else {
                    update_post_meta($order_id, 'export_success', '0');
                    $status = 2;
                    if ($res_data['data'] == 1) {
                        $status = 5;
                    }
                    $wpdb->update(
                        $order_cron,
                        array(
                            'status'            => $status,
                            'woo_shirtee_error' => $res_data['msg'],
                        ),
                        array(
                            'ID'     => $order->ID
                        )
                    );
                    $shirtee_importer_obj->send_emails("<p>{$res_data['msg']}.</p>", "Sync order to shirtee ".$order_id);
                    continue;
                }
            }
        }
    } catch (EXCEPTION $e) {
        $wpdb->update(
            $order_cron,
            array(
                'status'            => 2,
                'woo_shirtee_error' => $e->getMessage(),
            ),
            array(
                'ID'                => $order->ID
            )
        );
        $shirtee_importer_obj->send_emails("<p>".$e->getMessage().".</p>", "Sync order to shirtee");
        return false;
    }
}