<?php

// Exit if accessed directly


if (!defined('ABSPATH')) {
    exit;
}

// To remove incompatibility issue with Woocommerce HPOS
add_action( 'before_woocommerce_init', function() {
    if ( class_exists( \Automattic\WooCommerce\Utilities\FeaturesUtil::class ) ) {
        \Automattic\WooCommerce\Utilities\FeaturesUtil::declare_compatibility( 'custom_order_tables', 'shirtee-products-1/functions.php', true );
    }
} );

add_action('admin_init', 'shirtee_admin_init');

function shirtee_admin_init()
{       


    shirtee_set_version();
    /* Show notice only new version is available */
    $myUpdateChecker = PucFactory::buildUpdateChecker(
        'https://apibridge.shirtee.cloud/woo_api/stage_check/details.json',
        SHIRTEE_ROOT_DIR.'functions.php',
        'shirtee-products-1',
        1
    );
    if (!empty($myUpdateChecker)) {
        $checked_version = $myUpdateChecker->optionName;
        $latest = get_option($checked_version, false);
        if (!empty($latest) && !empty($latest->update) && $latest->update->version > PLUGIN_VERSION) {
            add_action('admin_notices', 'shirtee_admin_notice');
        }
    }

    /* Checke system status like memory*/
    if( isset($_GET['page']) && ($_GET['page'] == "dashboard" || $_GET['page'] == "shirtee-products" || $_GET['page'] == "shirtee-create-products" || $_GET['page'] == "shirtee-orders" || $_GET['page'] == "add-settings" || $_GET['page'] == "help-guide" ) ){
        $exe_time_system = ini_get('max_execution_time');
        $execution_time = '360';
        if ($exe_time_system < $execution_time) {
            add_action('admin_notices', 'system_status_notice');
        }
        $input_time_system = ini_get('max_input_time');
        $input_time = '600';
        if ($input_time_system < $input_time) {
            add_action('admin_notices', 'system_status_notice');
        }
    }
}
/* Code for adding <meta> of Product */
function custom_shirtee_meta_tags() {
    if(is_singular('product')){
        global $post;
        $meta_title = get_post_meta( $post->ID, 'meta_title', true );
        $meta_keyword = get_post_meta( $post->ID, 'meta_keyword', true );
        $meta_description = get_post_meta( $post->ID, 'meta_description', true );
        if(!empty($meta_title)){
            echo '<meta name="meta_title" content="'.$meta_title.'" />';
        }
        if(!empty($meta_keyword)){
            echo '<meta name="meta_keyword" content="'.$meta_keyword.'" />';
        }
        if(!empty($meta_description)){
            echo '<meta name="meta_description" content="'.$meta_description.'" />';
        }
    }
}
add_action('wp_head', 'custom_shirtee_meta_tags');
function system_status_notice(){    
    $exe_time_system = ini_get('max_execution_time');
    $execution_time = '360';
    $class   = '';
    $message = "";
    if ($exe_time_system < $execution_time && $exe_time_system != "-1" ) {
        $class   = 'error notice-warning shirtee-notice';
        $message .= __('<mark class="error"><span class="dashicons dashicons-warning"></span>PHP execution time is: '.$exe_time_system.' - We recommend setting execution time to at least '.$execution_time.' so please increase.</mark><br>', 'shirtee-products-1');
    }

    $input_time_system = ini_get('max_input_time');
    $input_time = '600';
    
    if ($input_time_system < $input_time && $input_time_system != "-1" ) {
        $class   = 'error notice-warning shirtee-notice';
        $message .= __('<mark class="error"><span class="dashicons dashicons-warning"></span>PHP input time is: '.$input_time_system.' - We recommend setting input time to at least '.$input_time.' so please increase.</mark><br>', 'shirtee-products-1');
    }    
    printf('<div class="%1$s"><p>%2$s</p></div>', esc_attr($class), $message);
}

function shirtee_set_version()
{
    $db_version     = get_option('shirtee_db_version', false);
    $plugin_version = get_option('shirtee_plugin_version', false);
    if (version_compare($plugin_version, PLUGIN_VERSION, '<')) {
        update_option('shirtee_plugin_version', PLUGIN_VERSION, false);

        require_once(SHIRTEE_ROOT_DIR.'/includes/classes/class-shirtee-products-importer.php');
        $shirtee_importer_obj = new SHIRTEE_IMPORTER();
        global $wpdb;
        $tbl_settings = "{$wpdb->prefix}shirtee_import_settings";
        $settings      = $shirtee_importer_obj->shirtee_settings();
        $account_info = unserialize($shirtee_importer_obj->shirtee_settings('account_info'));
        $settings['version']  = PLUGIN_VERSION;
        $data = array(
            'site_name' => get_option("blogname"),
            'settings'  => $settings,
            'account_info' => $account_info,
            'type'      => SHIRTEE_APP
        );
        
        $res_data = $shirtee_importer_obj->execute_curl($data, 'check_auth');                                
        
        if ( isset($res_data['status']) && ($res_data['status'] == 'success') ) {
            if (isset($res_data['data']['designer_details'])) {
                $designer_details       = $res_data['data']['designer_details'];
                $settings['designer_id'] = $designer_details['designer_id'];
                $full_name = '';
                if (isset($designer_details['prefix'])) {
                    $full_name = $designer_details['prefix'];
                }
                if (isset($designer_details['first_name'])) {
                    $full_name .= !empty($full_name) ? " " . $designer_details['first_name'] : $designer_details['first_name'];
                }
                if (isset($designer_details['middle_name'])) {
                    $full_name .= !empty($full_name) ? " " . $designer_details['middle_name'] : $designer_details['middle_name'];
                }
                if (isset($designer_details['last_name'])) {
                    $full_name .= !empty($full_name) ? " " . $designer_details['last_name'] : $designer_details['last_name'];
                }
                $full_name = addslashes($full_name);
                $settings['full_name'] = $full_name;

                
            }
            if (!empty($settings)) {
                $submit = $wpdb->update(
                    $tbl_settings,
                    array(
                        'settings_value'  => serialize($settings)
                    ),
                    array(
                        'settings_name'   => "import_settings"
                    )
                );
            } else {
                $submit = $wpdb->insert(
                    $tbl_settings,
                    array(
                        'settings_name'   => "import_settings",
                        'settings_value'  => serialize($settings)
                    )
                );
            }

            // Account detail 
            if(!empty($account_info)){

                $submit = $wpdb->update(
                    $tbl_settings,
                    array(
                        'settings_value'  => serialize($account_info),
                    ),
                    array(
                        'settings_name'   => "account_info",
                    )
                );  

            } else {

                $submit = $wpdb->insert(
                    $tbl_settings,
                    array(                                
                        'settings_name'   => "account_info",
                        'settings_value'  => serialize($account_info),

                    )
                );
            }
            if (isset($res_data['data']['access_token'])) {
                if (!empty($access_token)) {
                    $wpdb->update(
                        $tbl_settings,
                        array(
                            'settings_value' => "{$res_data['data']['access_token']}",
                        ),
                        array(
                            'settings_name'  => "access_token"
                        )
                    );
                } else {
                    $wpdb->insert(
                        $tbl_settings,
                        array(
                            'settings_name'  => "access_token",
                            'settings_value' => $res_data['data']['access_token']
                        )
                    );
                }
            }
        }
    }

    if (version_compare($db_version, DB_VERSION, '<')) {
        global $wpdb;
        $settings_table = "{$wpdb->prefix}shirtee_import_settings";
        $orders_table   = "{$wpdb->prefix}shirtee_import_woo_orders";

        $wpdb->query("ALTER TABLE {$orders_table} CHANGE `woo_shirtee_id` `woo_shirtee_id` TEXT NOT NULL");
        //$wpdb->query( "ALTER TABLE {$orders_table} ADD `woo_shirtee_error` TEXT NULL" );
        
        $wpdb->query("ALTER TABLE {$settings_table} CHANGE `settings_name` `settings_name` VARCHAR(30) NOT NULL");
        $wpdb->query("ALTER TABLE {$settings_table} CHANGE `settings_value` `settings_value` TEXT NOT NULL");
        
        update_option('shirtee_db_version', DB_VERSION, false);
    }
}

function shirtee_admin_notice()
{
    $class   = 'notice notice-warning shirtee-notice';
    $message = __('The new version of SHIRTEE plugin is available.Please <a href="'.admin_url('/plugins.php?#'.SHIRTEE_PRODUCTS_FOLDER.'-update').'">click here</a> to update plugin...', 'shirtee-products-1');
    printf('<div class="%1$s"><p>%2$s</p></div>', esc_attr($class), $message);
}

/*Woocommerce customization*/
add_filter('woocommerce_ajax_variation_threshold', 'shirtee_wc_ajax_variation_threshold', 10, 2);
add_action('woocommerce_before_add_to_cart_button', 'shirtee_product_custom_text');
add_filter('woocommerce_add_to_cart_validation', 'shirtee_validate_custom_field', 10, 3);
add_filter('woocommerce_add_cart_item_data', 'shirtee_add_custom_field_item_data', 10, 3);
add_action('woocommerce_before_calculate_totals', 'shirtee_before_calculate_totals', 10, 1);
add_filter('woocommerce_cart_item_name', 'shirtee_cart_item_name', 10, 3);
add_action('woocommerce_checkout_create_order_line_item', 'shirtee_add_custom_data_to_order', 10, 4);

function shirtee_wc_ajax_variation_threshold($qty, $product)
{
    $settings = SHIRTEE_IMPORTER::shirtee_settings();
    return $varLimit = isset($settings['varLimit']) && $settings['varLimit'] != '' ? $settings['varLimit'] : 200;
}
function wpse_rest_batch_items_limit( $limit ) {
    $settings = SHIRTEE_IMPORTER::shirtee_settings();
    return $varLimit = isset($settings['varLimit']) && $settings['varLimit'] != '' ? $settings['varLimit'] : 200;
}
add_filter( 'woocommerce_rest_batch_items_limit', 'wpse_rest_batch_items_limit' );
/**
 * Display custom field on the front end
 * @since 1.0.0
 */
function shirtee_product_custom_text()
{
    $customize = get_post_meta(get_the_ID(), 'is_customize', true);
    if ($customize == 1) {
        echo '<div class="shirtee-custom-field-wrapper"><label for="shirtee-title-field">Custom Text</label><input type="text" id="shirtee-title-field" name="shirtee-title-field" maxlength="64" value=""></div>';
    } else {
        return false;
    }
}

/**
* Validate the text field
* @since 1.0.0
* @param Array 		$passed					Validation status.
* @param Integer   $product_id     Product ID.
* @param Boolean  	$quantity   		Quantity
*/
function shirtee_validate_custom_field($passed, $product_id, $quantity)
{
    $customize = get_post_meta($product_id, 'is_customize', true);
    if ($customize == 1) {
        if (empty($_POST['shirtee-title-field'])) {
            $passed = false;
            wc_add_notice(__('Please enter a value into the text field', 'shirtee-products-1'), 'error');
        }
    }
    return $passed;
}

/**
* Add the text field as item data to the cart object
* @since 1.0.0
* @param Array 	   $cart_item_data Cart item meta data.
* @param Integer   $product_id     Product ID.
* @param Integer   $variation_id   Variation ID.
*/
function shirtee_add_custom_field_item_data($cart_item_data, $product_id, $variation_id)
{
    $customize = get_post_meta($product_id, 'is_customize', true);
    if ($customize == 1) {
        if (!empty($_POST['shirtee-title-field'])) {
            $cart_item_data['title_field'] = $_POST['shirtee-title-field'];
        }
    }
    return $cart_item_data;
}

/**
* Update the price in the cart
* @since 1.0.0
*/
function shirtee_before_calculate_totals($cart_obj)
{
    if (is_admin() && ! defined('DOING_AJAX')) {
        return;
    }
    // Iterate through each cart item
    foreach ($cart_obj->get_cart() as $key => $value) {
        if (isset($value['total_price'])) {
            $price = $value['total_price'];
            $value['data']->set_price(($price));
        }
    }
}

/**
* Display the custom field value in the cart
* @since 1.0.0
*/
function shirtee_cart_item_name($name, $cart_item, $cart_item_key)
{
    if (isset($cart_item['title_field'])) {
        $name .= sprintf(
            '<p>Custom Field :%s</p>',
            esc_html($cart_item['title_field'])
        );
    }
    return $name;
}

/**
* Add custom field to order object
*/
function shirtee_add_custom_data_to_order($item, $cart_item_key, $values, $order)
{
    foreach ($item as $cart_item_key => $values) {
        if (isset($values['title_field'])) {
            $item->add_meta_data(__('Custom Field', 'shirtee-products-1'), $values['title_field'], true);
        }
    }
}

function shirtee_products_count($status = 'all',$product_type='all')
{
    global $wpdb;
    $insertedData = $wpdb->prefix. "shirtee_import_products";
    $select       = "SELECT COUNT('ID') FROM $insertedData WHERE status NOT IN(0,3)";
    if ($status == '0') {
        $select  .= " AND product_woo_id != 0";
    } elseif ($status == '1') {
        $select  .= " AND product_woo_id = 0";
    }
    if ($product_type != 'all' && $product_type != '') {
        $select  .= " AND product_title = '".$product_type."'";
    }
    $products = $wpdb->get_var($select);
    return $products;
}

function sm_display_product_color_options($html, $args)
{
    $swatch_types = array(
        'size'  => 'Size',
        'color' => 'Color'
    );
    $attr = shirtee_get_tax_attribute($args['attribute']);
    // Return if this is normal attribute
    if (empty($attr)) {
        return $html;
    }

    if (!array_key_exists($attr->attribute_name, $swatch_types)) {
        return $html;
    }

    $options   = $args['options'];
    $product   = $args['product'];
    $attribute = $args['attribute'];
    $class     = "variation-selector variation-select-{$attr->attribute_name}";
    $swatches  = '';
    $color_selected = ''; //default selected code

    if (empty($options) && ! empty($product) && ! empty($attribute)) {
        $attributes = $product->get_variation_attributes();
        $options    = $attributes[$attribute];
    }
    if (array_key_exists($attr->attribute_name, $swatch_types)) {
        if (!empty($options) && $product && taxonomy_exists($attribute)) {
            // Get terms if this is a taxonomy - ordered. We need the names too.
            //$terms = wc_get_product_terms($product->get_id(), $attribute, array('fields' => 'all'));
            $terms = wc_get_product_terms($product->get_id(), $attribute, array('fields' => 'all','orderby' => 'term_id', 'order' => 'ASC'));
            if($attribute == 'pa_color' && ( count($terms) == 1) ){ //default selected code
                    $color_selected = ''; //default selected code
            } //default selected code
            foreach ($terms as $term) {
                if ($attr->attribute_name == 'color') {
                    $color = get_term_meta($term->term_id, 'color_code', true);
                    if (empty($color)) {
                        return $html;
                    }
                }
                if (in_array($term->slug, $options)) {
                    $swatches .= apply_filters('shirtee_swatch_html', '', $term, $attr->attribute_name, $args, $color_selected); //default selected code
                }
            }
        }
        if (!empty($swatches)) {
            $class .= ' hidden';
            $swatches = "<div class='shirtee-swatches swatchers-{$attr->attribute_name}' data-attribute_name='attribute_" . esc_attr( $attribute ) . "'>" . $swatches . "</div>";
            $html     = '<div class="' . esc_attr($class) . '">' . $html . '</div>' . $swatches;
        }
    }
    return $html;
}

add_filter('woocommerce_dropdown_variation_attribute_options_html', 'sm_display_product_color_options', 100, 2);
   

add_filter('shirtee_swatch_html', 'swatch_html', 5, 5); //default selected code

function shirtee_get_tax_attribute($taxonomy)
{
    global $wpdb;
    $attr = substr($taxonomy, 3);
    $attr = $wpdb->get_row("SELECT * FROM {$wpdb->prefix}woocommerce_attribute_taxonomies WHERE attribute_name = '{$attr}'");
    return $attr;
}

function swatch_html($html, $term, $type, $args, $color_selected) //default selected code
{   
     $settings = SHIRTEE_IMPORTER::shirtee_settings();
     if(isset($settings['product_swatches'])){
        $product_swatches = $settings['product_swatches'];
     }else{
        $product_swatches = 0;
    } 
    if($product_swatches == 1){
        $selected = sanitize_title($args['selected']) == $term->slug ? 'selected' : '';
        $name     = esc_html(apply_filters('woocommerce_variation_option_name', $term->name));
        switch($type) {
            case 'size':
                $html = sprintf(
                    '<span class="swatch swatch-size swatch-%s %s" title="%s" data-value="%s">%s</span>',
                    esc_attr($term->slug),
                    $selected,
                    esc_attr($name),
                    esc_attr($term->slug),
                    $name
                );
                break;

            case 'color':
                $color = '#'. get_term_meta($term->term_id, 'color_code', true);
                $border = '';
                if ($color == '#') $border = 'border:2px solid #ccc';
                if ($color == '#ffffff' || $color == '#fff') $border = 'border:2px solid #ccc';
                list($r, $g, $b) = sscanf($color, "#%02x%02x%02x");
                $html = sprintf(
                    "<span class='swatch swatch-color {$color_selected} swatch-%s %s' style='background-color:%s;color:%s;{$border}' title='%s' data-value='%s'>%s</span>", //default selected code
                    esc_attr($term->slug),
                    $selected,
                    esc_attr($color),
                    "rgba($r, $g, $b, 0.5)",
                    esc_attr($name),
                    esc_attr($term->slug),
                    $name
                );
                break;
            }
            return $html;
    }
}
// A callback function to add a custom field to our "pa_color" taxonomy
function shirtee_taxonomy_custom_fields($tag)
{
    $t_id = $tag->term_id;
    $color_code = get_term_meta($t_id, 'color_code', true); ?>
    <tr class="form-field">
        <th scope="row" valign="top">
            <label for="presenter_id"><?php _e('Color Code', 'shirtee-products-1'); ?></label>
        </th>
        <td>
            <input type="text" name="color_code" size="6" value="<?php echo $color_code != '' ? $color_code : ''; ?>"><br />
        </td>
    </tr>
    <?php
}
// Add the fields to the "pa_color" taxonomy, using our callback function
add_action('pa_color_edit_form_fields', 'shirtee_taxonomy_custom_fields', 10, 2);

// A callback function to save our extra taxonomy field(s)
function save_taxonomy_custom_fields($term_id)
{
    if (isset($_POST['color_code'])) {
        $color_code = $_POST['color_code'];
        if (strlen($color_code) < 6) return false;
        update_term_meta($term_id, 'color_code', $_POST['color_code']);
    }
}
// Save the changes made on the "presenters" taxonomy, using our callback function
add_action('edited_pa_color', 'save_taxonomy_custom_fields', 10, 2);

add_action('woocommerce_email_after_order_table', 'add_order_email_instructions', 10, 2);
function add_order_email_instructions($order, $sent_to_admin)
{
    if (!$sent_to_admin) {
        if ($order->get_status() == 'completed') {
            $tracking = $order->get_meta('tracking_id');
            $carrier  = $order->get_meta('tracking_carrier');

            echo '<h2>'.__('Tracking Information', 'woocommerce').'</h2>';
            echo "<p>Tracking Number :: {$tracking}</p>";
            echo "<p>Tracking Carrier :: {$carrier}</p>";
        }
    }
}

function remove_product_info($product_mage_id, $post_id)
{
    if ($post_id == 0 || empty($post_id)) return;
    $oldVariation = array(
        'post_type'      => 'product_variation',
        'posts_per_page' => -1,
        'post_parent'    => $post_id
    );
    $variations = get_posts($oldVariation);
    if (!empty($variations)) {
        foreach ($variations as $vars) {
            wp_delete_post($vars->ID);
        }
    }
    if (has_post_thumbnail($post_id)) {
        wp_delete_attachment(get_post_thumbnail_id($post_id));
    }
    $gallery_image = explode(",", get_post_meta($post_id, '_product_image_gallery', true));
    if (!empty($gallery_image)) {
        foreach ($gallery_image as $image) {
            wp_delete_attachment($image);
        }
    }
    if (!empty($post_id) && $post_id != 0) {
        wp_delete_post($post_id);
    }
}

function store_product_information($post_id, $post_data)
{
    generate_product_meta_data($post_id, $post_data);
    if (isset($post_data['images'])) {
        attach_product_images($post_id, $post_data);
    }
    if (isset($post_data['tags'])) {
        store_seo_tags($post_id, $post_data);
    }
    if (isset($post_data['options'])) {
        store_product_variation($post_id, $post_data);
    }
}

function generate_product_meta_data($post_id, $post_data)
{
    /* Product all meta values */
    update_post_meta($post_id, '_sku', $post_data['sku']);
    update_post_meta($post_id, '_weight', $post_data['weight']);
    update_post_meta($post_id, '_length', $post_data['length']);
    update_post_meta($post_id, '_width', $post_data['width']);
    update_post_meta($post_id, '_height', $post_data['height']);
    update_post_meta($post_id, 'design_ID', $post_data['designer_id']);
    update_post_meta($post_id, 'product_imported', 'yes');
    update_post_meta($post_id, '_manage_stock', 'yes');
    update_post_meta($post_id, '_stock_status', 'instock');
    update_post_meta($post_id, '_stock', 10000);
    update_post_meta($post_id, '_low_stock_amount', 10);
    update_post_meta($post_id, '_backorders', 'no');
    if ($post_data['is_customize_product'] == 1) {
        update_post_meta($post_id, 'is_customize', 1);
    }
}

function attach_product_images($post_id, $post_data)
{
    global $wpdb;
    $posts = "{$wpdb->prefix}posts";
    /* Product images and measurement image */
    if (!empty($post_data['images'])) {
        $atachments = [];
        foreach ($post_data['images'] as $img) {
            $image_name = "{$post_data['sku']}-{$img['label']}-{$img['position']}";
            $image_id   = $wpdb->get_row("SELECT ID,post_parent FROM {$posts} WHERE post_name LIKE '%".sanitize_title($image_name)."%'");
            if (!empty($image_id)) {
                if ($image_id->post_parent == 0 || empty($image_id->post_parent)) {
                    $wpdb->update(
                        $posts,
                        array(
                            'post_parent' => $post_id
                        ),
                        array(
                            'ID'          => $image_id->ID
                        )
                    );
                }
                if ($img['position'] == 0) {
                    set_post_thumbnail($post_id, $image_id->ID);
                } else {
                    if (!in_array($image_id->ID, $atachments)) {
                        $atachments[] = $image_id->ID;
                    }
                }
            }
        }
        /*Mesurement Image*/
        $m_image_id = $wpdb->get_row("SELECT ID,post_parent FROM {$posts} WHERE post_name LIKE '%".sanitize_title($post_data['sku'].'-measure')."%'");
        if (!empty($m_image_id)) {
            if ($m_image_id->post_parent == 0 || empty($m_image_id->post_parent)) {
                $wpdb->update(
                    $posts,
                    array(
                        'post_parent' => $post_id
                    ),
                    array(
                        'ID'          => $m_image_id->ID
                    )
                );
            }
            if (!in_array($m_image_id->ID, $atachments)) {
                $atachments[] = $m_image_id->ID;
            }
        }
        /*Mesurement Image*/
        if (!empty($atachments)) {
            update_post_meta($post_id, '_product_image_gallery', implode(",", $atachments));
        }
    }
}

function updateProductImages($post_id,$sku,$images)
{
    global $wpdb;
    $posts = "{$wpdb->prefix}posts";
    /* Product images and measurement image */
    if (!empty($images)) {
        $atachments = [];
        
        //image add link to post id attachment
        foreach( $images as $image ){
            $wpdb->update(
                $posts,
                array(
                    'post_parent' => $post_id
                ),
                array(
                    'ID'          => $image['id']
                )
            );

        }

        /*Mesurement Image*/
        $m_image_id = $wpdb->get_row("SELECT ID,post_parent FROM {$posts} WHERE post_name LIKE '%".sanitize_title($sku.'-measure')."%'");
        if (!empty($m_image_id)) {
            if ($m_image_id->post_parent == 0 || empty($m_image_id->post_parent)) {
                $wpdb->update(
                    $posts,
                    array(
                        'post_parent' => $post_id
                    ),
                    array(
                        'ID'          => $m_image_id->ID
                    )
                );
            }
           
            $gvalue = get_post_meta( $post_id,  $key = '_product_image_gallery', $single = true );
            if(!empty($gvalue)){                    
                $atachments = explode(",",$gvalue);
            }
            $atachments[] = $m_image_id->ID;
            
            update_post_meta($post_id, '_product_image_gallery', implode(",", $atachments));
                
            
        }
        
    }
}

function store_seo_tags($post_id, $post_data)
{
    /* Product SEO Friendly tags */
    $tags = $post_data['tags'];
    if (!empty($tags)) {
        $pTags = explode(",", $tags);
        for ($t=0; $t<count($pTags); $t++) {
            $tag_name = ucfirst($pTags[$t]);
            $tag_slug = sanitize_title($pTags[$t]);
            // Check if the Term exist and if not we create it.
            if (!term_exists($tag_name, 'product_tag')) {
                    $insert_tag = wp_insert_term(
                        $tag_name,
                        'product_tag',
                        array(
                            'slug' => $tag_slug
                        )
                    );
            }
            // Set attribute values
            $set_tag = wp_set_post_terms($post_id, array($tag_name), 'product_tag', true);
        }
    }
}

function store_product_variation($post_id, $post_data)
{
    global $wpdb;
    $posts = "{$wpdb->prefix}posts";
    //require_once( SHIRTEE_ROOT_DIR. '/includes/classes/class-shirtee-config.php' );
    $lang     = "de";
    $settings = SHIRTEE_IMPORTER::shirtee_settings();
    if (!empty($settings)) {
        $lang = isset($settings['lang']) ? $settings['lang'] : 'de';
    }
    $option_names    = ShirteeConfig::get_attributes($lang);
    $option_names_en = ShirteeConfig::get_attributes('en');
    /**
     * Check for live product and if it has variation than create
     * Variable product
     */
    if (!empty($post_data['options'])) {
        $attribute = array_values($post_data['options']);
        /* If only one variation in the product than not needs to create as variable product */
        if (count($attribute[0]['additional_fields']) == 1 && count($attribute[1]['additional_fields']) == 1) {
            wp_set_object_terms($post_id, 'simple', 'product_type');
            update_post_meta($post_id, '_regular_price', $post_data['price']);
            update_post_meta($post_id, '_price', $post_data['price']);
        } else {
            wp_set_object_terms($post_id, 'variable', 'product_type');
            foreach ($attribute as $options) { //Main option loop
                $taxonomy = wc_attribute_taxonomy_name($option_names_en[$options['title']]);
                $taxonomy_name = ucfirst($option_names[$options['title']]);
                $taxonomy_slug = (wc_sanitize_taxonomy_name($option_names_en[$options['title']]));
                // NEW Attributes: Register and save them
                if (!taxonomy_exists($taxonomy)) {
                    $register = register_taxonomy(
                        $taxonomy,
                        'product',
                        array(
                            'label'   => $taxonomy_name,
                            'rewrite' => array('slug' => $taxonomy_slug)
                        )
                    );
                    $attr_args = array(
                        'attribute_label'   => $taxonomy_name,
                        'attribute_name'    => $taxonomy_slug,
                        'attribute_type'    => 'select',
                        'attribute_orderby' => 'menu_order',
                        'attribute_public'  => 0
                    );
                    if (!empty($register)) {
                        $attr_args['attribute_id'] = $register;
                    }
                    $wpdb->insert("{$wpdb->prefix}woocommerce_attribute_taxonomies", $attr_args);
                    delete_transient('wc_attribute_taxonomies');
                }
                foreach ($options['additional_fields'] as $term) {
                    $term_name = ucfirst($term['title']);
                    $term_slug = sanitize_title($term['title']);
                    // Check if the Term exist and if not we create it.
                    if (!term_exists($term_name, $taxonomy)) {
                        $insert_term = wp_insert_term(
                            $term_name,
                            $taxonomy,
                            array(
                                'slug' => $term_slug
                            )
                        );
                        if ($taxonomy == 'pa_color' && array_key_exists('color_code', $term)) {
                            update_term_meta($insert_term['term_id'], 'color_code', $term['color_code']);
                        }
                    } elseif ($taxonomy == 'pa_color' && array_key_exists('color_code', $term)) {
                        $term_id = get_term_by('slug', $term_slug, $taxonomy);
                        update_term_meta($term_id->term_id, 'color_code', $term['color_code']);
                    }
                    // Set attribute values
                    $set_term = wp_set_post_terms($post_id, array($term_name), $taxonomy, true);
                }
                $productAttributes[$taxonomy] = array (
                    'name'         => $taxonomy,
                    'value'        => '',
                    'position'     => '',
                    'is_visible'   => 1,
                    'is_variation' => 1,
                    'is_taxonomy'  => 1
                );
            }
            // Create a variations
            if (count($post_data['options']) > 1) { //ensure that size and color is exists
                $next     = next($post_data['options']);
                $nextKey  = key($post_data['options']);
                $keys     = array_keys($post_data['options']);
                $firstKey = $keys[0];
                if ($nextKey && $firstKey) {
                    $i = 1;
                    foreach ($post_data['options'][$firstKey]['additional_fields'] as $options) {
                        foreach ($post_data['options'][$nextKey]['additional_fields'] as $vars) {
                            // Check if variation is already exists or not.
                            $oldVariation = array(
                                'post_type'       => 'product_variation',
                                'post_status'     => array('publish', 'trash'),
                                'meta_query'      => array(
                                    'relation'    => 'OR',
                                    array(
                                        'key'     => '_sku',
                                        'value'   => "{$post_data['sku']}--{$options['sku']}--{$vars['value_id']}",
                                        'compare' => '='
                                    ),
                                    array(
                                        'key'     => '_sku',
                                        'value'   => "{$post_data['sku']}__{$options['sku']}__{$vars['value_id']}",
                                        'compare' => '='
                                    ),
                                )
                            );
                            $variations = get_posts($oldVariation);
                            if (empty($variations)) {
                                $userID = isset($post_data['user_id']) && !empty($post_data['user_id']) ? $post_data['user_id'] : 1;
                                $my_post = array(
                                    'post_author' => $userID,
                                    'post_title'  => 'Variation #' . $i . ' - '. $options['title']. ' - '.$vars['title'].' - '.$post_id,
                                    'post_name'   => 'product-' . $post_id . '-variation-' . $i,
                                    'post_status' => 'publish',
                                    'post_parent' => $post_id, //post is a child post of product post
                                    'post_type'   => 'product_variation', //set post type to product_variation
                                    'guid'        => home_url("/?product_variation=product-{$post_id}-variation-{$i}"),
                                    'menu_order'  => $i
                                );
                                $attID = wp_insert_post($my_post);
                            } else {
                                $attID = $variations[0]->ID;
                            }

                            $variation = new WC_Product_Variation($attID);

                            update_post_meta($attID, 'attribute_model_key', $post_data['sku']);
                            /* Custom Data for Attributes */
                            $varSize  = wc_attribute_taxonomy_name($option_names_en[$post_data['options'][$firstKey]['title']]);
                            $varColor = wc_attribute_taxonomy_name($option_names_en[$post_data['options'][$nextKey]['title']]);
                            update_post_meta($attID, 'attribute_'.sanitize_title($varSize), sanitize_title($options['title']));
                            update_post_meta($attID, 'attribute_'.$post_data['options'][$firstKey]['title'].'_key', $firstKey);
                            update_post_meta($attID, 'attribute_'.$post_data['options'][$firstKey]['title'].'_mage_id', $options['value_id']);
                            update_post_meta($attID, 'attribute_'.sanitize_title($varColor), sanitize_title($vars['title']));
                            update_post_meta($attID, 'attribute_'.$post_data['options'][$nextKey]['title'].'_key', $nextKey);
                            update_post_meta($attID, 'attribute_'.$post_data['options'][$nextKey]['title'].'_mage_id', $vars['value_id']);
                            
                            /* update_post_meta($attID, '_manage_stock', 'no');
                            update_post_meta($attID, '_stock_status', '');
                            update_post_meta($attID, '_stock', 10000);
                            update_post_meta($attID, '_backorders', 'no');
                            update_post_meta($attID, '_low_stock_amount', '');
                            update_post_meta($attID, '_sold_individually', 'no');
                            update_post_meta($attID, '_price', $post_data['price']); */

                            $variation->set_stock_quantity(10000);
                            $variation->set_manage_stock(true);
                            $variation->set_stock_status('');
                            $variation->set_price($post_data['price']);
                            $variation->set_regular_price($post_data['price']);
                            $variation->set_sku("{$post_data['sku']}--{$options['sku']}--{$vars['value_id']}");
                            $variation->save(); // Save the data

                            $image_name = $post_data['sku']."-".$vars['value_id']."-";
                            $page = $wpdb->get_row("SELECT ID FROM {$posts} WHERE post_name LIKE '%".sanitize_title($image_name)."%' ORDER BY ID ASC");
                            if ($page) {
                                update_post_meta($attID, '_thumbnail_id', $page->ID);
                            }
                            /* update_post_meta($attID, '_sku', "{$post_data['sku']}--{$options['sku']}--{$vars['value_id']}");
                            update_post_meta($attID, '_regular_price', $post_data['price']); */
                            $i++;
                        }
                    }
                }
            }
            update_post_meta($post_id, '_product_attributes', $productAttributes);
        }
    } else {
        wp_set_object_terms($post_id, 'simple', 'product_type');
        update_post_meta($post_id, '_regular_price', $post_data['price']);
        update_post_meta($post_id, '_price', $post_data['price']);
    }
}
function generateSignature($request_m,$request_u, $timestamp, $nonce, $signatureMethod, $version,$key,$key_s)//rest api singature generate
{
    $base = $request_m . "&" . rawurlencode($request_u) . "&"
        . rawurlencode("oauth_consumer_key=" . rawurlencode($key)
        . "&oauth_nonce=" . rawurlencode($nonce)
        . "&oauth_signature_method=" . rawurlencode($signatureMethod)
        . "&oauth_timestamp=" . $timestamp
        . "&oauth_version=" . $version);
    $key_s = rawurlencode($key_s) . '&' ;
    $signature = base64_encode(hash_hmac('sha1', $base, $key_s, true));

    return $signature;
}
function productAttributeCreate($post_data) // product attribute create
{
    global $wpdb;  
    $lang     = "de";
    $settings = SHIRTEE_IMPORTER::shirtee_settings();
    if (!empty($settings)) {
        $lang = isset($settings['lang']) ? $settings['lang'] : 'de';
    }
    $option_names    = ShirteeConfig::get_attributes($lang);
    $option_names_en = ShirteeConfig::get_attributes('en');
    $postData = array();

    if (!empty($post_data['options'])) {            
        $post_data['options'] = array_values($post_data['options']);        
		$i=0;
        foreach( $post_data['options']  as $attr ){
			if( $i < 2 ){
				$taxonomy_name = ucfirst($option_names[$attr['title']]);                 
				$taxonomy = wc_attribute_taxonomy_name($option_names_en[$attr['title']]);                
				$taxonomy_slug = (wc_sanitize_taxonomy_name($option_names_en[$attr['title']]));
				// NEW Attributes: Register and save them
				if (!taxonomy_exists($taxonomy)) {
					$register = register_taxonomy(
						$taxonomy,
						'product',
						array(
							'label'   => $taxonomy_name,
							'rewrite' => array('slug' => $taxonomy_slug)
						)
					);
					$attr_args = array(
						'attribute_label'   => $taxonomy_name,
						'attribute_name'    => $taxonomy_slug,
						'attribute_type'    => 'select',
						'attribute_orderby' => 'menu_order',
						'attribute_public'  => 0
					);
					if (!empty($register)) {
						$attr_args['attribute_id'] = $register;
					}
					$wpdb->insert("{$wpdb->prefix}woocommerce_attribute_taxonomies", $attr_args);
					delete_transient('wc_attribute_taxonomies');
				}
			}
            $i++;
        }
        
        $terms = wc_get_attribute_taxonomy_ids();       
        if (count($post_data['options']) > 1) { //ensure that size and color is exists
            $optionsData = array();
            $i=0;
            foreach ($post_data['options'] as $options) {   
				if( $i < 2 ){
					$taxonomy_name = ucfirst($option_names[$options['title']]); 
					$optionsData[$i]['id']= $terms[$options['title']];                    
					$optionsData[$i]['position']= 0;                       
					$optionsData[$i]['visible']= true;
					$optionsData[$i]['variation']= true;
					foreach( $options['additional_fields'] as $additional_fields ){                        
						$optionsData[$i]['options'][] = $additional_fields['title']; 
					}
				}
                $i++;
            } 
            return $optionsData;
        }            
        
    } 
}
function restApiCurlData($url, $vartionData){ //rest api curl request
    $ch = curl_init($url);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    $headers = ['Content-Type: application/json'];
    curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);                
    curl_setopt($ch, CURLOPT_HTTPAUTH, CURLAUTH_BASIC);
    curl_setopt($ch, CURLOPT_POST, true);
    curl_setopt($ch, CURLOPT_POSTFIELDS, $vartionData);
    $response = curl_exec($ch);
    $error = curl_error($ch);
    curl_close($ch);
    $res_data = json_decode($response, true);
    return $res_data;
    
}
function restApiUrl($store_url,$consumer_key,$consumer_secret){
    $time           = time();
    $anounce        = $time;
    $cunsumkey      = $consumer_key;
    $cunsumseckey   = $consumer_secret;                
    $signkey        = generateSignature('POST',$store_url,time(),$anounce,'HMAC-SHA1','1.0',$cunsumkey,$cunsumseckey);
    $url            = $store_url."?oauth_consumer_key=".$cunsumkey."&oauth_signature_method=HMAC-SHA1&oauth_timestamp=".$time."&oauth_nonce=".$anounce."&oauth_version=1.0&oauth_signature=".$signkey; 
    return $url;
}
function create_measure_image($data) //create measure image
{
    $lang     = "de";
    $settings = SHIRTEE_IMPORTER::shirtee_settings();

    if (!empty($settings)) {
        $lang = isset($settings['lang']) ? $settings['lang'] : 'de';
    }

    if (empty($lang)) 
    {
        $lang = "german";

    } elseif (!empty($lang) && $lang == 'es') {

        $lang = "spanish";

    } elseif (!empty($lang) && $lang == 'fr') {

        $lang = "french";

    } elseif (!empty($lang) && $lang == 'it') {

        $lang = "italian";

    } elseif (!empty($lang) && $lang == '' || $lang == 'de') {

        $lang = "german";

    } elseif (!empty($lang) && $lang == 'en') {

        $lang = "english";

    } elseif (!empty($lang) && $lang == 'sv') {

        $lang = "swedish";

    } elseif (!empty($lang) && $lang == 'pt') {

        $lang = "portuguese";

    } elseif (!empty($lang) && $lang == 'pl') {

        $lang = "polish";

    } elseif (!empty($lang) && $lang == 'nl') {

        $lang = "dutch";

    } else {
        
        $lang = "german";
    }

    $url = "https://dashboard.shirtee.cloud/v1/Mimage?sku={$data['sku']}&lan=".$lang;
    $ch  = curl_init();
    curl_setopt($ch, CURLOPT_URL, $url);
    curl_setopt($ch, CURLOPT_POST, 0);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
    $response = curl_exec($ch);
    curl_close($ch);
    $res_data = json_decode($response, true);
    if ($res_data['status'] == 1 && $res_data['message'] == "success") {
        $ext      = pathinfo($res_data['url'], PATHINFO_EXTENSION);
        $filename = "{$data['sku']}-measure";
        create_image_if_not_exists($filename, $res_data['url'], "{$data['sku']}-Measure", true);
        return true;
    }
}

/**
 * Create image if not exists
 *
 */
function create_image_if_not_exists($image_name, $image_url, $image_title, $measure = false)
{
    global $wpdb;
    $posts = "{$wpdb->prefix}posts";
    $upload_dir = wp_upload_dir(); // Set upload folder
    $page = $wpdb->get_row("SELECT ID FROM {$posts} WHERE post_name LIKE '%".sanitize_title($image_name)."%'");
    if (!empty($page)) {
        $attach_id = $page->ID;
        $attached_file_url = get_post_meta($attach_id, "_wp_attached_file", true);
        if (!empty($attached_file_url)) {
            $image_file_name = "{$upload_dir['basedir']}/{$attached_file_url}";
            $check_attach_meta = get_post_meta($attach_id, "_wp_attachment_metadata", true);
            if (empty($check_attach_meta)) {
                $status = create_image($image_url, $image_file_name, $measure);
                include_once ABSPATH . 'wp-admin/includes/image.php';
                $attach_data = wp_generate_attachment_metadata($attach_id, $image_file_name);
                wp_update_attachment_metadata($attach_id, $attach_data);
            }
        }
    } else {
        $file_ext = "jpeg";
        if (strpos($image_url, "&ext")) {
            $ext = explode("&ext=", $image_url);
            if (strpos($ext[1], "&") !== false) {
                $properExt = explode("&", $ext[1]);
                $file_ext  = $properExt[0] != '' ? $properExt[0] : "jpeg";
            } else {
                $file_ext = $ext[1] != '' ? $ext[1] : "jpeg";
            }
        } elseif ($measure === true) {
            $file_ext = pathinfo($image_url, PATHINFO_EXTENSION);
        }

        $file = "{$upload_dir['basedir']}/{$image_name}";
        if (wp_mkdir_p($upload_dir['path'])) {
            $file = "{$upload_dir['path']}/{$image_name}";
        }
        $image_file_name = "{$file}.{$file_ext}";
        
        if (!file_exists($image_file_name) || filesize($image_file_name) <= 0) {
            $status = create_image($image_url, $image_file_name, $measure);
        }
        $mimetype = mime_content_type($image_file_name);
        $attachment = array(
            'post_author'    => 1,
            'post_mime_type' => $mimetype,
            'post_title'     => $image_title,
            'post_name'      => sanitize_title($image_file_name),
            'post_content'   => '',
            'post_status'    => 'inherit'
        );
        $attach_id = wp_insert_attachment($attachment, $image_file_name);
        include_once ABSPATH . 'wp-admin/includes/image.php';
        $attach_data = wp_generate_attachment_metadata($attach_id, $image_file_name);
        wp_update_attachment_metadata($attach_id, $attach_data);
    }
}

/**
 * Create image to Wpp store for measurement image
 * 
 */
function create_image($img_url, $file, $measure = false)
{
    $open_file = $file;
    if (file_exists($open_file)) {
        unlink($open_file);
    }
    if ($measure === true) {
        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL, $img_url);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
        $response = curl_exec($ch);
        curl_close($ch);
        $fp = fopen($open_file, 'x');
        fwrite($fp, $response);
        fclose($fp);
        return true;
    } else {
        $options = array(
            CURLOPT_RETURNTRANSFER => true,  // return web page
            CURLOPT_HEADER         => false, // don't return headers
            CURLOPT_FOLLOWLOCATION => true,  // follow redirects
            CURLOPT_AUTOREFERER    => true,  // set referer on redirect
            CURLOPT_MAXREDIRS      => 5,     // stop after 5 redirects
        );
        $ch      = curl_init($img_url);
        curl_setopt_array($ch, $options);
        $content = curl_exec($ch);
        $header  = curl_getinfo($ch);
        curl_close($ch);
        if (!empty($header['url'])) {
            $file_url = $header['url'];
            $ch = curl_init();
            curl_setopt($ch, CURLOPT_URL, $file_url);
            curl_setopt($ch, CURLOPT_HEADER, 0);
            curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
            $result = curl_exec($ch);
            curl_close($ch);
            $fp = fopen($open_file, 'x');
            fwrite($fp, $result);
            fclose($fp);
            return true;
        }
    }
}
function createVariation($sku,$attribute,$product_images,$regular_price,$warehouse){

    $settings   = SHIRTEE_IMPORTER::shirtee_settings();
    $lang       = "de";
    if (!empty($settings)) {
        $lang = isset($settings['lang']) ? $settings['lang'] : 'de';
    }
    $option_names = ShirteeConfig::get_attributes($lang);
    global $wpdb;
    $posts = "{$wpdb->prefix}posts";

    $colorLable = array();
    $varData    = array();
    foreach( $product_images as $lableData){
        $colorLable[] = $lableData['label'];
    }
    $main = 0;    
    $terms = wc_get_attribute_taxonomy_ids();

	if( $warehouse == 1 ){
        $sizeTitle = $attribute[0]['title'];
        $colorTitle = $attribute[1]['title'];
        $size  = $attribute[0]['additional_fields'];
        foreach( $attribute[2]['warehouse_variation'] as $variation ){					
            $value      = $sku."-".$variation['colorId'];	
            $image_id   = $wpdb->get_results("SELECT ID FROM {$posts} WHERE post_title= '".$value."' and post_type='attachment'"); 
            $pid        = "";
            if( !empty($image_id)){
                $pid    = $image_id[0]->ID;
            } 
                                    
           
            
            //if( isset($variation['ean_sku']) && !empty($variation['ean_sku']) ){
              //  $varData[$main]['sku']                      = $variation['ean_sku'];
            //} else {
            	$varData[$main]['sku']                      = $variation['sku'];
                $varData[$main]['regular_price']            = "$regular_price"; 
                $varData[$main]['image']['id']              = $pid;  
                $varData[$main]['manage_stock']             = true;
                $varData[$main]['stock_quantity']           = $variation['available_stock'];
            //}
            $varData[$main]['attributes'][0]['id']      = $terms['size'];//'Grösse';
            $varData[$main]['attributes'][0]['option']  = $variation['size'];						
            $varData[$main]['attributes'][1]['id']    =   $terms['color'];//'Grösse';
            $varData[$main]['attributes'][1]['option']  = $variation['color'];
            
            $main++;
        }    
    }  else {
        $sizeTitle = $attribute[0]['title'];
        $colorTitle = $attribute[1]['title'];
        $size  = $attribute[0]['additional_fields'];
        foreach( $size as $singleSize ){
            $sizeTitel = $singleSize['sku'];
			$title = $singleSize['title'];
			
            $sizeValue = $singleSize['value_id'];
			if( isset($singleSize['colors']) ){
				$colorArray = $singleSize['colors'];
				
				foreach( $attribute[1]['additional_fields'] as $color ){
					//$color
					if ( in_array($color['value_id'], $colorLable) && in_array($color['value_id'], $colorArray) ){
						$value      = $sku."-".$color['value_id'];
						$image_id   = $wpdb->get_results("SELECT ID FROM {$posts} WHERE post_title= '".$value."' and post_type='attachment'");
						$pid        = "";
						if( !empty($image_id)){
							$pid    = $image_id[0]->ID;
						} 

						//color code insert
						$taxonomy = wc_attribute_taxonomy_name("color");
						$term_name = ucfirst($color['title']);
						$term_slug = sanitize_title($color['title']);
						// Check if the Term exist and if not we create it.
						if (!term_exists($term_name, $taxonomy)) {
							$insert_term = wp_insert_term(
								$term_name,
								$taxonomy,
								array(
									'slug' => $term_slug
								)
							);
							
							if ($taxonomy == 'pa_color' ) {
								update_term_meta($insert_term['term_id'], 'color_code', $color['color_code']);
							}
						} elseif ($taxonomy == 'pa_color') {
							$term_id = get_term_by('slug', $term_slug, $taxonomy);
							update_term_meta($term_id->term_id, 'color_code', $color['color_code']);
						}
						//color code insert

						$varData[$main]['image']['id']              = $pid;                            
						$varData[$main]['regular_price']            = "$regular_price"; 
						$varData[$main]['sku']                      = $sku."__".$sizeTitel."__".$color['value_id'];						
						$varData[$main]['attributes'][0]['id']    = $terms['size'];//'Grösse';						
						$varData[$main]['attributes'][0]['option']  = $title;						
						$varData[$main]['attributes'][1]['id']    =  $terms['color'];//'Grösse';
						$varData[$main]['attributes'][1]['option']  = $color['title'];
						$varData[$main]['manage_stock']             = true;
						$varData[$main]['stock_quantity']           = "10000";
						$main++;
					}
				}
			}
        }
    } 
    return  $varData;
    
}
function createAlloverVariation($sku,$attribute,$product_images,$regular_price){

    $settings   = SHIRTEE_IMPORTER::shirtee_settings();
    $lang       = "de";
    if (!empty($settings)) {
        $lang = isset($settings['lang']) ? $settings['lang'] : 'de';
    }
    $option_names = ShirteeConfig::get_attributes($lang);
    global $wpdb;
    $posts = "{$wpdb->prefix}posts";

    $colorLable = array();
    $varData    = array();
    foreach( $product_images as $lableData){
        $colorLable[] = $lableData['label'];
    }
    $main = 0;    
    $terms = wc_get_attribute_taxonomy_ids();


    if( $attribute[0]['title']== "size" ){
        $sizeTitle = $attribute[0]['title'];
        $colorTitle = $attribute[1]['title'];
        $size  = $attribute[0]['additional_fields'];
        foreach( $size as $singleSize ){
            $sizeTitel = $singleSize['sku'];
			$title = $singleSize['title'];
            $sizeValue = $singleSize['value_id'];			
			$i=1;
			foreach( $attribute[1]['additional_fields'] as $color ){
				//$color					
					$value      = $sku."-".$i;
					
					$image_id   = $wpdb->get_results("SELECT ID FROM {$posts} WHERE post_title= '".$value."' and post_type='attachment'"); 
					$pid        = "";
					if( !empty($image_id)){
						$pid    = $image_id[0]->ID;
					} 

					

					$varData[$main]['image']['id']              = $pid;                            
					$varData[$main]['regular_price']            = "$regular_price"; 
					$varData[$main]['sku']                      = $sku."__".$sizeTitel."__".$color['value_id'];
					//$varData[$main]['attributes'][0]['name']    = ucfirst($option_names[ $sizeTitle ] );//'Grösse';
					$varData[$main]['attributes'][0]['id']    = $terms['size'];//'Grösse';
					//$varData[$main]['attributes'][0]['option']  = $sizeTitel;
					$varData[$main]['attributes'][0]['option']  = $title;
					//$varData[$main]['attributes'][1]['name']    = ucfirst($option_names[ $colorTitle ] ); //'Farbe';
					$varData[$main]['attributes'][1]['id']    = $terms['color'];//'Grösse';
					$varData[$main]['attributes'][1]['option']  = $color['title'];
					$varData[$main]['manage_stock']             = true;
					$varData[$main]['stock_quantity']           = "10000";
					$main++;
					$i++;
				
			}			 
        }
    } 
    return  $varData;
    
}
function countVariation($attribute,$product_images){
    
    $attribute = array_values($attribute );

    global $wpdb;
    $posts = "{$wpdb->prefix}posts";

    $colorLable = array();
    $varData    = array();
    foreach( $product_images as $lableData){
        $colorLable[] = $lableData['label'];
    }
    $count = 0;
    if( $attribute[0]['title']== "size" ){
        $sizeTitle = $attribute[0]['title'];
        $colorTitle = $attribute[1]['title'];
        $size  = $attribute[0]['additional_fields'];
        foreach( $size as $singleSize ){            
            $colorArray = $singleSize['colors'];
            foreach( $attribute[1]['additional_fields'] as $color ){
              //  if ( in_array($color['value_id'], $colorLable) && in_array($color['value_id'], $colorArray) ){
                    $count++;
              //  }
            }
        }
    } 
    return  $count;
}

/*---------------------------------------------------------
    
                Shirtee REST API

-----------------------------------------------------------*/

function sync_wooordertoshirtee(){
    register_rest_route( 'shirtee-products-1', '/syncwooordertoshirtee/', array(
        'methods' => 'GET',
        'callback' => 'sync_woo_ordertoshirtee_api',
        'show_in_index' => false,
        'permission_callback' => '__return_true',
    ));
}


function sync_woo_ordertoshirtee_api($data){

    $data = $data->get_param('limit');

    //if ($data == '1') {
    
        $d = date("j-M-Y H:i:s e").' == SH File cron logs ==';
        $str = ' SH File cron logs ';
        error_log("[$d] [$str]", 3, SHIRTEE_ROOT_DIR ."/wordpress.log");

        $res = require_once( SHIRTEE_ROOT_DIR. '/includes/cron/wooorder_to_shirtee_cron.php' );
        return $res;
        
    //}

    echo '<pre/>';print_r($res);exit;

}

add_action( 'rest_api_init', 'sync_wooordertoshirtee' );

/*---------------------------------------------------------------*/

function view_shirtee_settings_api(){
    register_rest_route( 'shirtee-products-1', '/get_shirtee_settings/', array(
        'methods' => 'POST',
        'callback' => 'share_shirtee_settings',
        'show_in_index' => false,
        'permission_callback' => '__return_true',
    ));
}

add_action( 'rest_api_init', 'view_shirtee_settings_api' );

// Get a random post
function share_shirtee_settings($data)
{   
    $data = $data->get_param('data');
    
    $str = json_encode($data);
    
    $settings = '';

    $d = date("j-M-Y H:i:s e").' == share_shirtee_settings date ==';
    error_log("[$d] [$str]", 3, SHIRTEE_ROOT_DIR ."/wordpress.log");
    
    if (in_array('view_settings', $data)) {
    
        $shirtee_importer_obj = new SHIRTEE_IMPORTER();
        $settings = $shirtee_importer_obj->shirtee_settings();
        if (empty($settings)) {
            echo json_encode(array("status" => "error", "msg" => "Settings not founds..."));
            exit;
        }
        $system_status = $shirtee_importer_obj->get_environment_info();
        $system = array();
        $system['memory_limit'] = size_format($system_status['wp_memory_limit']);
        $system['php_max_execution_time'] = $system_status['php_max_execution_time'];
        $system['php_input_time'] = $system_status['php_max_input_time'];
        $system['max_upload_size'] = size_format($system_status['max_upload_size']);
        $system['php_post_max_size'] = size_format($system_status['php_post_max_size']);
        $system['plugin_version'] = PLUGIN_VERSION;
       
        echo json_encode(array("status" => "success", "msg" => $settings, "system" => $system));
        exit;
    } elseif (in_array('product_insert', $data)) {
       if (empty($_POST)) { $_POST = $data; }
       require_once( SHIRTEE_ROOT_DIR. '/includes/cron/product_insert_restapi_cron.php' ); 

    } elseif (in_array('product_update', $data)) {
        if (empty($_POST)) { $_POST = $data; }
        require_once( SHIRTEE_ROOT_DIR. '/includes/cron/product_update_restapi_cron.php' );

    } elseif (in_array('dropShipping_fetch_products', $data)) {

        if (empty($_POST)) { $_POST = $data; }
            
        $res = require_once( SHIRTEE_ROOT_DIR. '/includes/classes/class-shirtee-bridge.php' );

        return $res;

    } elseif (in_array('fetch_product_data', $data)) {
        
        $res = require_once( SHIRTEE_ROOT_DIR. '/includes/cron/fetch_products_cron.php' );
        return $res;

    } elseif (in_array('schedule_product', $data)) {
        
        if (empty($_POST)) { $_POST = $data; }
            
        $res = require_once( SHIRTEE_ROOT_DIR. '/includes/classes/class-shirtee-bridge.php' );

        return $res;

    } elseif (in_array('update_wallet', $data)) {
        
        if (empty($_POST)) { $_POST = $data; }
            
        $res = require_once( SHIRTEE_ROOT_DIR. '/includes/classes/class-shirtee-bridge.php' );

        return $res;

    } elseif (in_array('cron_list', $data)) {
        
        if (empty($_POST)) { $_POST = $data; }
            
        $res = require_once( SHIRTEE_ROOT_DIR. '/includes/classes/class-shirtee-bridge.php' );

        return $res;

    } elseif (in_array('sync_products', $data)) {
        
        if (empty($_POST)) { $_POST = $data; }
            
        $res = require_once( SHIRTEE_ROOT_DIR. '/includes/classes/class-shirtee-bridge.php' );

        return $res;

    } elseif (in_array('product_list', $data)) {
        
        if (empty($_POST)) { $_POST = $data; }
            
        $res = require_once( SHIRTEE_ROOT_DIR. '/includes/classes/class-shirtee-bridge.php' );

        return $res;

    } elseif (in_array('import_to_woocommerce', $data)) {
        
        if (empty($_POST)) { $_POST = $data; }
            
        $res = require_once( SHIRTEE_ROOT_DIR. '/includes/classes/class-shirtee-bridge.php' );

        return $res;

    } elseif (in_array('order_list', $data)) {
        
        if (empty($_POST)) { $_POST = $data; }
            
        $res = require_once( SHIRTEE_ROOT_DIR. '/includes/classes/class-shirtee-bridge.php' );

        return $res;

    } elseif (in_array('resync_order', $data)) {
        
        if (empty($_POST)) { $_POST = $data; }
            
        $res = require_once( SHIRTEE_ROOT_DIR. '/includes/classes/class-shirtee-bridge.php' );

        return $res;

    } elseif (in_array('woo_remove_api_token', $data)) {
        
        if (empty($_POST)) { $_POST = $data; }
            
        $res = require_once( SHIRTEE_ROOT_DIR. '/includes/classes/class-shirtee-bridge.php' );

        return $res;

    } elseif (in_array('woo_shirtee_id_update', $data)) {
        
        if (empty($_POST)) { $_POST = $data; }
            
        $res = require_once( SHIRTEE_ROOT_DIR. '/includes/classes/class-shirtee-bridge.php' );

        return $res;

    } elseif (in_array('remove_woo_shirtee_id', $data)) {
        
        if (empty($_POST)) { $_POST = $data; }
            
        $res = require_once( SHIRTEE_ROOT_DIR. '/includes/classes/class-shirtee-bridge.php' );

        return $res;

    } elseif (in_array('remove_products', $data)) {
        
        if (empty($_POST)) { $_POST = $data; }
            
        $res = require_once( SHIRTEE_ROOT_DIR. '/includes/classes/class-shirtee-bridge.php' );

        return $res;

    } elseif (in_array('migrate_data', $data)) {
        
        if (empty($_POST)) { $_POST = $data; }
            
        $res = require_once( SHIRTEE_ROOT_DIR. '/includes/classes/class-shirtee-bridge.php' );

        return $res;

    } elseif (in_array('warehouse_stock_update', $data)) {
        
        if (empty($_POST)) { $_POST = $data; }
            
        $res = require_once( SHIRTEE_ROOT_DIR. '/includes/classes/class-shirtee-bridge.php' );

        return $res;

    } elseif (in_array('allImportProduct_fetch_products', $data)) {
        
        if (empty($_POST)) { $_POST = $data; }
            
        $res = require_once( SHIRTEE_ROOT_DIR. '/includes/classes/class-shirtee-bridge.php' );

        return $res;

    } elseif (in_array('warehouse_fetch_products', $data)) {
        
        if (empty($_POST)) { $_POST = $data; }
            
        $res = require_once( SHIRTEE_ROOT_DIR. '/includes/classes/class-shirtee-bridge.php' );

        return $res;

    } elseif (in_array('updatetracking', $data)) {
        
        if (empty($_POST)) { $_POST = $data; }
            
        $res = require_once( SHIRTEE_ROOT_DIR. '/includes/cron/order_status.php' );

        return $res;

    } elseif (in_array('update_shirtee_settings', $data)) {
        
        if (empty($_POST)) { $_POST = $data; }
            
        $res = require_once( SHIRTEE_ROOT_DIR. '/includes/classes/class-shirtee-bridge.php' );

        return $res;

    } else {

        echo json_encode(array("status" => "fail", "msg" => 'Somthing wants wrong please check again!'));
    }
    
    return $settings;
}

?>