<?php
/**
 * This file represents an example of the code that themes/plugin would use to register
 * the required plugins.
 *
 * It is expected that theme/plugins authors would copy and paste this code into their
 * functions.php file, and amend to suit.
 *
 * @see http://tgmpluginactivation.com/configuration/ for detailed documentation.
 *
 * @package    TGM-Plugin-Activation
 * @subpackage Example
 * @version    2.6.1 for plugin Shirtee Products Importer
 * @author     Thomas Griffin, Gary Jones, Juliette Reinders Folmer
 * @copyright  Copyright (c) 2011, Thomas Griffin
 * @license    http://opensource.org/licenses/gpl-2.0.php GPL v2 or later
 * @link       https://github.com/TGMPA/TGM-Plugin-Activation
 */

/**
 * Include the TGM_Plugin_Activation class.
 *
 * Depending on your implementation, you may want to change the include call:
 *
 * Parent Theme:
 * require_once get_template_directory() . '/path/to/class-tgm-plugin-activation.php';
 *
 * Child Theme:
 * require_once get_stylesheet_directory() . '/path/to/class-tgm-plugin-activation.php';
 *
 * Plugin:
 * require_once dirname( __FILE__ ) . '/path/to/class-tgm-plugin-activation.php';
 */
require_once ( 'class-tgm-plugin-activation.php' );

if( !function_exists( 'shirtee_required_plugins_list' ) ){
	function shirtee_required_plugins_list(){
		return apply_filters( 'tgmpa_plugin_list', array(
			array(
				'name'              => esc_html__( 'Woocommerce', 'shirtee-products-1' ),
				'slug'              => 'woocommerce',
				'source'            => 'https://wordpress.org/plugins/woocommerce/',
				'required'          => true,
				'force_activation'  => false,
				'force_deactivation'=> false,
				'details_url'       => 'https://woocommerce.com/',
			),
		));
	}
	add_action( 'tgmpa_register', 'shirtee_register_required_plugins' );
}

/**
 * Register the required plugins for this plugin.
 *
 * In this example, we register one plugin:
 * - one included with the TGMPA library
 *
 * The variables passed to the `tgmpa()` function should be:
 * - an array of plugin arrays;
 * - optionally a configuration array.
 * If you are not changing anything in the configuration array, you can remove the array and remove the
 * variable from the function call: `tgmpa( $plugins );`.
 * In that case, the TGMPA default settings will be used.
 *
 * This function is hooked into `tgmpa_register`, which is fired on the WP `init` action on priority 10.
 */
function shirtee_register_required_plugins() {
	$plugins = shirtee_required_plugins_list();

	$tgmpa_id = 'shirtee'.'_recommended_plugins';

	/*
	 * Array of configuration settings. Amend each line as needed.
	 *
	 * TGMPA will start providing localized text strings soon. If you already have translations of our standard
	 * strings available, please help us make TGMPA even better by giving us access to these translations or by
	 * sending in a pull-request with .po file(s) with the translations.
	 *
	 * Only uncomment the strings in the config array if you want to customize the strings.
	 */
	$config = array(
		'id'           => $tgmpa_id,           // Unique ID for hashing notices for multiple instances of TGMPA.
		'default_path' => '',                  // Default absolute path to bundled plugins.
		'menu'         => 'required-plugins',   // Menu slug.
		'parent_slug'  => 'themes.php',  // Parent menu slug.
		'capability'   => 'edit_theme_options',// Capability needed to view plugin install page, should be a capability associated with the parent menu used.
		'has_notices'  => true,                // Show admin notices or not.
		'dismissable'  => false,               // If false, a user cannot dismiss the nag message.
		'is_automatic' => false,               // Automatically activate plugins after installation or not.
	);

	tgmpa( $plugins, $config );
}


?>